@@ -383,8 +383,6 @@ static void
 load_themes (DialogData *data)
 {
 	GFile        *style_dir;
-	int           visible_columns;
-	int           col_spacing;
 	GFile        *data_dir;
 	char         *default_theme;
 	GtkTreeModel *model;
@@ -406,11 +404,6 @@ load_themes (DialogData *data)
 
 	/**/
 
-	visible_columns = 3;
-	col_spacing = gtk_icon_view_get_item_padding (GTK_ICON_VIEW (GET_WIDGET ("theme_iconview")));
-	gtk_widget_set_size_request (GET_WIDGET ("theme_iconview"),
-				     (col_spacing * (visible_columns + 1) + (PREVIEW_SIZE + col_spacing * 2) * visible_columns),
-				     (PREVIEW_SIZE + col_spacing * 2));
 	gtk_widget_realize (GET_WIDGET ("theme_iconview"));
 
 	default_theme = g_settings_get_string (data->settings, PREF_CONTACT_SHEET_THEME);
@@ -709,7 +702,21 @@ dlg_contact_sheet (GthBrowser *browser,
 	data->builder = _gtk_builder_new_from_file ("contact-sheet.ui", "contact_sheet");
 	data->settings = g_settings_new (GTHUMB_CONTACT_SHEET_SCHEMA);
 
-	data->dialog = _gtk_builder_get_widget (data->builder, "contact_sheet_dialog");
+	data->dialog = g_object_new (GTK_TYPE_DIALOG,
+				     "title", _("Contact Sheet"),
+				     "transient-for", GTK_WINDOW (browser),
+				     "modal", FALSE,
+				     "destroy-with-parent", FALSE,
+				     "use-header-bar", _gtk_settings_get_dialogs_use_header (),
+				     NULL);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (data->dialog))),
+			   _gtk_builder_get_widget (data->builder, "dialog_content"));
+	gtk_dialog_add_buttons (GTK_DIALOG (data->dialog),
+				_GTK_LABEL_CANCEL, GTK_RESPONSE_CANCEL,
+				_GTK_LABEL_SAVE, GTK_RESPONSE_OK,
+				NULL);
+	_gtk_dialog_add_class_to_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK, GTK_STYLE_CLASS_SUGGESTED_ACTION);
+
 	gth_browser_set_dialog (browser, "contact_sheet", data->dialog);
 	g_object_set_data (G_OBJECT (data->dialog), "dialog_data", data);
 
@@ -832,11 +839,11 @@ dlg_contact_sheet (GthBrowser *browser,
 			  "delete-event",
 			  G_CALLBACK (dialog_delete_event_cb),
 			  data);
-	g_signal_connect (GET_WIDGET ("ok_button"),
+	g_signal_connect (gtk_dialog_get_widget_for_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK),
 			  "clicked",
 			  G_CALLBACK (ok_clicked_cb),
 			  data);
-	g_signal_connect_swapped (GET_WIDGET ("cancel_button"),
+	g_signal_connect_swapped (gtk_dialog_get_widget_for_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_CANCEL),
 				  "clicked",
 				  G_CALLBACK (close_dialog),
 				  data);
@@ -872,7 +879,5 @@ dlg_contact_sheet (GthBrowser *browser,
 
 	/* Run dialog. */
 
-	gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (browser));
-	gtk_window_set_modal (GTK_WINDOW (data->dialog), FALSE);
 	gtk_widget_show (data->dialog);
 }
