@@ -39,7 +39,7 @@
 using namespace std;
 
 
-#define INVALID_VALUE "---"
+#define INVALID_VALUE N_("(invalid value)")
 
 
 /* Some bits of information may be contained in more than one metadata tag.
@@ -244,39 +244,43 @@ create_metadata (const char *key,
 		 const char *category,
 		 const char *type_name)
 {
+	char            *formatted_value_utf8;
 	char            *attribute;
 	GthMetadataInfo *metadata_info;
 	GthMetadata     *metadata;
 	char            *description_utf8;
-	char            *formatted_value_utf8;
 
-	if (_g_utf8_all_spaces (formatted_value))
+	formatted_value_utf8 = _g_utf8_from_any (formatted_value);
+	if (_g_utf8_all_spaces (formatted_value_utf8))
 		return NULL;
 
+	description_utf8 = _g_utf8_from_any (description);
+
 	attribute = exiv2_key_to_attribute (key);
-	description_utf8 = g_locale_to_utf8 (description, -1, NULL, NULL, NULL);
 	if (attribute_is_date (attribute)) {
 		GTimeVal time_;
 
+		g_free (formatted_value_utf8);
+		formatted_value_utf8 = NULL;
+
 		if (_g_time_val_from_exif_date (raw_value, &time_))
 			formatted_value_utf8 = _g_time_val_strftime (&time_, "%x %X");
 		else
 			formatted_value_utf8 = g_locale_to_utf8 (formatted_value, -1, NULL, NULL, NULL);
-		if (formatted_value_utf8 == NULL)
-			formatted_value_utf8 = g_strdup (INVALID_VALUE);
 	}
-	else {
-		const char *formatted_clean;
+	else if (_g_utf8_has_prefix (formatted_value_utf8, "lang=")) {
+		int   pos;
+		char *formatted_clean;
 
-		if (strncmp (formatted_value, "lang=", 5) == 0)
-			formatted_clean = strchr (formatted_value, ' ') + 1;
-		else
-			formatted_clean = formatted_value;
-		formatted_value_utf8 = g_locale_to_utf8 (formatted_clean, -1, NULL, NULL, NULL);
-		if (formatted_value_utf8 == NULL)
-			formatted_value_utf8 = g_strdup (INVALID_VALUE);
+		pos = _g_utf8_first_ascii_space (formatted_value_utf8);
+		formatted_clean = _g_utf8_remove_prefix (formatted_value_utf8, pos + 1);
+		g_free (formatted_value_utf8);
+		formatted_value_utf8 = formatted_clean;
 	}
 
+	if (formatted_value_utf8 == NULL)
+		formatted_value_utf8 = g_strdup (INVALID_VALUE);
+
 	metadata_info = gth_main_get_metadata_info (attribute);
 	if ((metadata_info == NULL) && (category != NULL)) {
 		GthMetadataInfo info;
@@ -451,6 +455,8 @@ set_attribute_from_metadata (GFileInfo  *info,
 	char *formatted_value;
 	char *raw_value;
 	char *type_name;
+	char *formatted_value_utf8;
+	char *raw_value_utf8;
 
 	if (metadata == NULL)
 		return;
@@ -528,11 +534,16 @@ set_string_list_attribute_from_tagset (GFileInfo  *info,
 
 	if (GTH_IS_METADATA (metadata) && (gth_metadata_get_data_type (GTH_METADATA (metadata)) != GTH_METADATA_TYPE_STRING_LIST)) {
 		char           *raw;
+		char           *utf8_raw;
 		char          **keywords;
 		GthStringList  *string_list;
 
 		g_object_get (metadata, "raw", &raw, NULL);
-		keywords = g_strsplit (raw, ",", -1);
+		utf8_raw = _g_utf8_try_from_any (raw);
+		if (utf8_raw == NULL)
+			return;
+
+		keywords = g_strsplit (utf8_raw, ",", -1);
 		string_list = gth_string_list_new_from_strv (keywords);
 		metadata = (GObject *) gth_metadata_new_for_string_list (string_list);
 		g_file_info_set_attribute_object (info, attribute, metadata);
@@ -541,6 +552,7 @@ set_string_list_attribute_from_tagset (GFileInfo  *info,
 		g_object_unref (string_list);
 		g_strfreev (keywords);
 		g_free (raw);
+		g_free (utf8_raw);
 	}
 	else
 		g_file_info_set_attribute_object (info, attribute, metadata);
