@@ -91,6 +91,7 @@ get_histogram_value (GthHistogram        *histogram,
 		     Method               method)
 {
 	double h = gth_histogram_get_value (histogram, channel, bin);
+
 	switch (method) {
 	case METHOD_EQUALIZE_SQUARE_ROOT:
 		return (h >= 2) ? sqrt (h) : h;
@@ -99,6 +100,8 @@ get_histogram_value (GthHistogram        *histogram,
 	default:
 		g_assert_not_reached ();
 	}
+
+	return 0;
 }
 
 
@@ -205,7 +208,6 @@ adjust_contrast_setup (EqualizeData    *equalize_data,
 		       cairo_surface_t *source)
 {
 	GthHistogram *histogram;
-	int           c;
 
 	histogram = gth_histogram_new ();
 	gth_histogram_calculate_for_image (histogram, source);
@@ -357,8 +359,8 @@ image_task_completed_cb (GthTask  *task,
 
 	if (self->priv->apply_to_original) {
 		if (self->priv->destination != NULL) {
-			GtkWidget *window;
-			GtkWidget *viewer_page;
+			GtkWidget     *window;
+			GthViewerPage *viewer_page;
 
 			window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
 			viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
@@ -485,7 +487,7 @@ gth_file_tool_adjust_contrast_get_options (GthFileTool *base)
 {
 	GthFileToolAdjustContrast *self;
 	GtkWidget                 *window;
-	GtkWidget                 *viewer_page;
+	GthViewerPage             *viewer_page;
 	GtkWidget                 *viewer;
 	cairo_surface_t           *source;
 	GtkWidget                 *options;
@@ -529,7 +531,8 @@ gth_file_tool_adjust_contrast_get_options (GthFileTool *base)
 				    METHOD_STRETCH_0_5,
 				    get_image_task_for_method (METHOD_STRETCH_0_5),
 				    _("Stretch"),
-				    _("Stretch the histogram trimming the 0.5%"));
+				    /* xgettext:no-c-format */
+				    _("Stretch the histogram after trimming 0.5% from both ends"));
 	gth_filter_grid_add_filter (GTH_FILTER_GRID (filter_grid),
 				    METHOD_EQUALIZE_SQUARE_ROOT,
 				    get_image_task_for_method (METHOD_EQUALIZE_SQUARE_ROOT),
@@ -564,7 +567,7 @@ gth_file_tool_adjust_contrast_destroy_options (GthFileTool *base)
 {
 	GthFileToolAdjustContrast *self;
 	GtkWidget                 *window;
-	GtkWidget                 *viewer_page;
+	GthViewerPage             *viewer_page;
 
 	self = (GthFileToolAdjustContrast *) base;
 
@@ -576,7 +579,7 @@ gth_file_tool_adjust_contrast_destroy_options (GthFileTool *base)
 	window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
 	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
 	gth_image_viewer_page_reset_viewer_tool (GTH_IMAGE_VIEWER_PAGE (viewer_page));
-	gth_viewer_page_update_sensitivity (GTH_VIEWER_PAGE (viewer_page));
+	gth_viewer_page_update_sensitivity (viewer_page);
 
 	_g_clear_object (&self->priv->builder);
 
