@@ -77,8 +77,7 @@ static void
 curves_setup (TaskData        *task_data,
 	      cairo_surface_t *source)
 {
-	long **value_map;
-	int    c, v;
+	int c, v;
 
 	for (c = GTH_HISTOGRAM_CHANNEL_VALUE; c <= GTH_HISTOGRAM_CHANNEL_BLUE; c++) {
 		task_data->value_map[c] = g_new (long, 256);
@@ -219,8 +218,8 @@ image_task_completed_cb (GthTask  *task,
 
 	if (self->priv->apply_to_original) {
 		if (self->priv->destination != NULL) {
-			GtkWidget *window;
-			GtkWidget *viewer_page;
+			GtkWidget     *window;
+			GthViewerPage *viewer_page;
 
 			window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
 			viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
@@ -242,7 +241,7 @@ static TaskData *
 task_data_new (GthPoints *points)
 {
 	TaskData *task_data;
-	int       c, n;
+	int       c;
 
 	task_data = g_new (TaskData, 1);
 	for (c = 0; c < GTH_HISTOGRAM_N_CHANNELS; c++) {
@@ -297,7 +296,6 @@ apply_cb (gpointer user_data)
 	GthFileToolCurves *self = user_data;
 	GtkWidget         *window;
 	GthPoints          points[GTH_HISTOGRAM_N_CHANNELS];
-	int                c;
 
 	if (self->priv->apply_event != 0) {
 		g_source_remove (self->priv->apply_event);
@@ -523,7 +521,6 @@ preset_changed_cb (GthCurvePreset	*preset,
 		   gpointer		 user_data)
 {
 	GthFileToolCurves *self = user_data;
-	gboolean           saved;
 	const char        *preset_name;
 	GthPoints         *points;
 	GError            *error = NULL;
@@ -603,7 +600,7 @@ static GtkWidget *
 gth_file_tool_curves_get_options (GthFileTool *base)
 {
 	GthFileToolCurves *self;
-	GtkWidget         *viewer_page;
+	GthViewerPage     *viewer_page;
 	GtkWidget         *viewer;
 	cairo_surface_t   *source;
 	GtkWidget         *options;
@@ -715,7 +712,6 @@ gth_file_tool_curves_get_options (GthFileTool *base)
 		self->priv->filter_grid = gth_filter_grid_new ();
 		for (i = 0; i < gth_curve_preset_get_size (self->priv->preset); i++) {
 			GthPoints  *points;
-			int         c;
 			const char *name;
 			int         id;
 
@@ -760,7 +756,7 @@ static void
 gth_file_tool_curves_destroy_options (GthFileTool *base)
 {
 	GthFileToolCurves *self;
-	GtkWidget         *viewer_page;
+	GthViewerPage     *viewer_page;
 
 	self = (GthFileToolCurves *) base;
 
@@ -771,7 +767,7 @@ gth_file_tool_curves_destroy_options (GthFileTool *base)
 
 	viewer_page = gth_image_viewer_page_tool_get_page (GTH_IMAGE_VIEWER_PAGE_TOOL (self));
 	gth_image_viewer_page_reset_viewer_tool (GTH_IMAGE_VIEWER_PAGE (viewer_page));
-	gth_viewer_page_update_sensitivity (GTH_VIEWER_PAGE (viewer_page));
+	gth_viewer_page_update_sensitivity (viewer_page);
 
 	_cairo_clear_surface (&self->priv->preview);
 	_cairo_clear_surface (&self->priv->destination);
@@ -808,17 +804,15 @@ gth_file_tool_curves_populate_headerbar (GthFileTool *base,
 					 GthBrowser  *browser)
 {
 	GthFileToolCurves *self;
-	gboolean           rtl;
 	GtkWidget         *button;
 
 	self = (GthFileToolCurves *) base;
 
 	/* reset button */
 
-	rtl = gtk_widget_get_direction (GTK_WIDGET (base)) == GTK_TEXT_DIR_RTL;
 	button = gth_browser_add_header_bar_button (browser,
 						    GTH_BROWSER_HEADER_SECTION_EDITOR_COMMANDS,
-						    rtl ? "edit-undo-rtl-symbolic" : "edit-undo-symbolic",
+						    "edit-undo-symbolic",
 						    _("Reset"),
 						    NULL,
 						    NULL);
@@ -883,8 +877,6 @@ gth_file_tool_sharpen_reset_image (GthImageViewerPageTool *base)
 static void
 gth_file_tool_curves_init (GthFileToolCurves *self)
 {
-	int c;
-
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_FILE_TOOL_CURVES, GthFileToolCurvesPrivate);
 	self->priv->preview = NULL;
 	self->priv->destination = NULL;
