@@ -197,8 +197,8 @@ image_task_completed_cb (GthTask  *task,
 
 	if (self->priv->apply_to_original) {
 		if (self->priv->destination != NULL) {
-			GtkWidget *window;
-			GtkWidget *viewer_page;
+			GtkWidget     *window;
+			GthViewerPage *viewer_page;
 
 			window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
 			viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
@@ -324,7 +324,7 @@ gth_file_tool_grayscale_get_options (GthFileTool *base)
 {
 	GthFileToolGrayscale *self;
 	GtkWidget            *window;
-	GtkWidget            *viewer_page;
+	GthViewerPage        *viewer_page;
 	GtkWidget            *viewer;
 	cairo_surface_t      *source;
 	GtkWidget            *options;
@@ -402,8 +402,8 @@ static void
 gth_file_tool_grayscale_destroy_options (GthFileTool *base)
 {
 	GthFileToolGrayscale *self;
-	GtkWidget             *window;
-	GtkWidget             *viewer_page;
+	GtkWidget            *window;
+	GthViewerPage        *viewer_page;
 
 	self = (GthFileToolGrayscale *) base;
 
@@ -415,7 +415,7 @@ gth_file_tool_grayscale_destroy_options (GthFileTool *base)
 	window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
 	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
 	gth_image_viewer_page_reset_viewer_tool (GTH_IMAGE_VIEWER_PAGE (viewer_page));
-	gth_viewer_page_update_sensitivity (GTH_VIEWER_PAGE (viewer_page));
+	gth_viewer_page_update_sensitivity (viewer_page);
 
 	_g_clear_object (&self->priv->builder);
 
