@@ -176,6 +176,15 @@ list_tools__gth_browser_construct_cb (GthBrowser *browser)
 	gtk_widget_show (button);
 	gtk_box_pack_start (GTK_BOX (gth_browser_get_headerbar_section (browser, GTH_BROWSER_HEADER_SECTION_BROWSER_TOOLS)), button, FALSE, FALSE, 0);
 
+	/* viewer edit */
+
+	button = _gtk_menu_button_new_for_header_bar ("tools-symbolic");
+	g_signal_connect (button, "toggled", G_CALLBACK (tools_menu_button_toggled_cb), data);
+	gtk_widget_set_tooltip_text (button, _("Tools"));
+	gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (button), menu);
+	gtk_widget_show (button);
+	gtk_box_pack_end (GTK_BOX (gth_browser_get_headerbar_section (browser, GTH_BROWSER_HEADER_SECTION_VIEWER_EDIT)), button, FALSE, FALSE, 0);
+
 	g_object_unref (builder);
 }
 
@@ -184,15 +193,23 @@ gpointer
 list_tools__gth_browser_file_list_key_press_cb (GthBrowser  *browser,
 						GdkEventKey *event)
 {
-	gpointer  result = NULL;
-	GList    *script_list;
-	GList    *scan;
+	gpointer         result = NULL;
+	guint            event_key;
+	GdkModifierType  event_modifiers;
+	GList           *script_list;
+	GList           *scan;
+
+	event_key = gdk_keyval_to_lower (event->keyval);
+	event_modifiers = event->state & gtk_accelerator_get_default_mod_mask ();
 
 	script_list = gth_script_file_get_scripts (gth_script_file_get ());
 	for (scan = script_list; scan; scan = scan->next) {
-		GthScript *script = scan->data;
+		GthScript       *script = scan->data;
+		guint            keyval;
+		GdkModifierType  modifiers;
 
-		if (gth_script_get_shortcut (script) == event->keyval) {
+		gth_script_get_accelerator (script, &keyval, &modifiers);
+		if ((keyval == event_key) && (modifiers == event_modifiers)) {
 			gth_browser_exec_script (browser, script);
 			result = GINT_TO_POINTER (1);
 			break;
