@@ -41,6 +41,7 @@ enum {
 
 struct _GthScriptEditorDialogPrivate {
 	GtkBuilder *builder;
+	GtkWidget  *accel_button;
   	char       *script_id;
   	gboolean    script_visible;
   	gboolean    wait_command;
@@ -115,9 +116,6 @@ gth_script_editor_dialog_construct (GthScriptEditorDialog *self,
 				    const char            *title,
 			            GtkWindow             *parent)
 {
-	GtkTreeIter  iter;
-	int          i;
-
 	if (title != NULL)
 		gtk_window_set_title (GTK_WINDOW (self), title);
 	if (parent != NULL)
@@ -133,28 +131,15 @@ gth_script_editor_dialog_construct (GthScriptEditorDialog *self,
 	self->priv->builder = gtk_builder_new_from_resource ("/org/gnome/gThumb/list_tools/data/ui/script-editor.ui");
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), _gtk_builder_get_widget (self->priv->builder, "script_editor"), TRUE, TRUE, 0);
 
+	self->priv->accel_button = gth_accel_button_new ();
+	gtk_widget_show (self->priv->accel_button);
+	gtk_box_pack_start (GTK_BOX (GET_WIDGET ("accel_box")), self->priv->accel_button, FALSE, FALSE, 0);
+
 	g_signal_connect (GET_WIDGET ("command_entry"),
 			  "icon-press",
 			  G_CALLBACK (command_entry_icon_press_cb),
 			  self);
 
-	gtk_list_store_append (GTK_LIST_STORE (GET_WIDGET ("shortcut_liststore")), &iter);
-	gtk_list_store_set (GTK_LIST_STORE (GET_WIDGET ("shortcut_liststore")), &iter,
-			    SHORTCUT_NAME_COLUMN, _("none"),
-			    -1);
-
-	for (i = 0; i <= 9; i++) {
-		char *value;
-
-		value = g_strdup_printf (_("key %d on the numeric keypad"), i);
-		gtk_list_store_append (GTK_LIST_STORE (GET_WIDGET ("shortcut_liststore")), &iter);
-		gtk_list_store_set (GTK_LIST_STORE (GET_WIDGET ("shortcut_liststore")), &iter,
-				    SHORTCUT_NAME_COLUMN, value,
-				    -1);
-
-		g_free (value);
-	}
-
 	/**/
 
 	gth_script_editor_dialog_set_script (self, NULL);
@@ -184,7 +169,7 @@ _gth_script_editor_dialog_set_new_script (GthScriptEditorDialog *self)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("shell_script_checkbutton")), TRUE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("for_each_file_checkbutton")), FALSE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("wait_command_checkbutton")), FALSE);
-	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("shortcut_combobox")), NO_SHORTCUT);
+	gth_accel_button_set_accelerator (GTH_ACCEL_BUTTON (self->priv->accel_button), 0, 0);
 }
 
 
@@ -192,11 +177,6 @@ void
 gth_script_editor_dialog_set_script (GthScriptEditorDialog *self,
 				     GthScript             *script)
 {
-	GtkTreeIter  iter;
-	GtkTreePath *path;
-	GList       *script_list;
-	GList       *scan;
-
 	g_free (self->priv->script_id);
 	self->priv->script_id = NULL;
 	self->priv->script_visible = TRUE;
@@ -204,7 +184,9 @@ gth_script_editor_dialog_set_script (GthScriptEditorDialog *self,
 	_gth_script_editor_dialog_set_new_script (self);
 
 	if (script != NULL) {
-		guint keyval;
+		guint            keyval;
+		GdkModifierType  modifiers;
+
 
 		self->priv->script_id = g_strdup (gth_script_get_id (script));
 		self->priv->script_visible = gth_script_is_visible (script);
@@ -215,43 +197,10 @@ gth_script_editor_dialog_set_script (GthScriptEditorDialog *self,
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("for_each_file_checkbutton")), gth_script_for_each_file (script));
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("wait_command_checkbutton")), gth_script_wait_command (script));
 
-		keyval = gth_script_get_shortcut (script);
-		if ((keyval >= GDK_KEY_KP_0) && (keyval <= GDK_KEY_KP_9))
-			gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("shortcut_combobox")), (keyval - GDK_KEY_KP_0) + 1);
-		else
-			gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("shortcut_combobox")), NO_SHORTCUT);
+		gth_script_get_accelerator (script, &keyval, &modifiers);
+		gth_accel_button_set_accelerator (GTH_ACCEL_BUTTON (self->priv->accel_button), keyval, modifiers);
 	}
 
-	if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (GET_WIDGET ("shortcut_liststore")), &iter)) {
-		do {
-			gtk_list_store_set (GTK_LIST_STORE (GET_WIDGET ("shortcut_liststore")), &iter,
-					    SHORTCUT_SENSITIVE_COLUMN, TRUE,
-					    -1);
-		}
-		while (gtk_tree_model_iter_next (GTK_TREE_MODEL (GET_WIDGET ("shortcut_liststore")), &iter));
-	}
-
-	script_list = gth_script_file_get_scripts (gth_script_file_get ());
-	for (scan = script_list; scan; scan = scan->next) {
-		GthScript *other_script = scan->data;
-		guint      keyval;
-
-		keyval = gth_script_get_shortcut (other_script);
-		if ((keyval >= GDK_KEY_KP_0) && (keyval <= GDK_KEY_KP_9)) {
-			if (g_strcmp0 (gth_script_get_id (other_script), self->priv->script_id) == 0)
-				continue;
-
-			path = gtk_tree_path_new_from_indices (keyval - GDK_KEY_KP_0 + 1, -1);
-			gtk_tree_model_get_iter (GTK_TREE_MODEL (GET_WIDGET ("shortcut_liststore")), &iter, path);
-			gtk_list_store_set (GTK_LIST_STORE (GET_WIDGET ("shortcut_liststore")), &iter,
-					    SHORTCUT_SENSITIVE_COLUMN, FALSE,
-					    -1);
-
-			gtk_tree_path_free (path);
-		}
-	}
-	_g_object_list_unref (script_list);
-
 	update_sensitivity (self);
 }
 
@@ -260,19 +209,17 @@ GthScript *
 gth_script_editor_dialog_get_script (GthScriptEditorDialog  *self,
 				     GError                **error)
 {
-	GthScript *script;
-	int        keyval_index;
-	guint      keyval;
+	GthScript       *script;
+	guint            keyval;
+	GdkModifierType  modifiers;
+	char            *accelerator;
 
 	script = gth_script_new ();
 	if (self->priv->script_id != NULL)
 		g_object_set (script, "id", self->priv->script_id, NULL);
 
-	keyval_index = gtk_combo_box_get_active (GTK_COMBO_BOX (GET_WIDGET ("shortcut_combobox")));
-	if ((keyval_index >= 1) && (keyval_index <= 10))
-		keyval = GDK_KEY_KP_0 + (keyval_index - 1);
-	else
-		keyval = GDK_KEY_VoidSymbol;
+	gth_accel_button_get_accelerator (GTH_ACCEL_BUTTON (self->priv->accel_button), &keyval, &modifiers);
+	accelerator = gtk_accelerator_name (keyval, modifiers);
 
 	g_object_set (script,
 		      "display-name", gtk_entry_get_text (GTK_ENTRY (GET_WIDGET ("name_entry"))),
@@ -281,7 +228,7 @@ gth_script_editor_dialog_get_script (GthScriptEditorDialog  *self,
 		      "shell-script", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("shell_script_checkbutton"))),
 		      "for-each-file", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("for_each_file_checkbutton"))),
 		      "wait-command", gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("wait_command_checkbutton"))),
-		      "shortcut", keyval,
+		      "accelerator", accelerator,
 		      NULL);
 
 	if (g_strcmp0 (gth_script_get_display_name (script), "") == 0) {
@@ -296,5 +243,7 @@ gth_script_editor_dialog_get_script (GthScriptEditorDialog  *self,
 		return NULL;
 	}
 
+	g_free (accelerator);
+
 	return script;
 }
