@@ -22,11 +22,7 @@
 #include <config.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#ifdef HAVE_LIBSOUP_GNOME
-#include <libsoup/soup-gnome.h>
-#else
 #include <libsoup/soup.h>
-#endif /* HAVE_LIBSOUP_GNOME */
 #ifdef HAVE_LIBSECRET
 #include <libsecret/secret.h>
 #endif /* HAVE_LIBSECRET */
@@ -376,11 +372,11 @@ show_authentication_error_dialog (WebService  *self,
 
 	dialog = _gtk_message_dialog_new (GTK_WINDOW (self->priv->browser),
 					  GTK_DIALOG_MODAL,
-					  GTK_STOCK_DIALOG_ERROR,
+					  _GTK_ICON_NAME_DIALOG_ERROR,
 					  _("Could not connect to the server"),
 					  (*error)->message,
-					  _("Choose _Account..."), WEB_AUTHENTICATION_RESPONSE_CHOOSE_ACCOUNT,
-					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					  _("Choose _Account…"), WEB_AUTHENTICATION_RESPONSE_CHOOSE_ACCOUNT,
+					  _GTK_LABEL_CANCEL, GTK_RESPONSE_CANCEL,
 					  NULL);
 	gth_task_dialog (GTH_TASK (self), TRUE, dialog);
 
@@ -410,7 +406,7 @@ set_current_account (WebService   *self,
 	if (self->priv->account == account)
 		return;
 
-	link = g_list_find_custom (self->priv->accounts, self->priv->account, (GCompareFunc) oauth_account_cmp);
+	link = g_list_find_custom (self->priv->accounts, account, (GCompareFunc) oauth_account_cmp);
 	if (link != NULL) {
 		self->priv->accounts = g_list_remove_link (self->priv->accounts, link);
 		_g_object_list_unref (link);
@@ -844,11 +840,7 @@ _web_service_send_message (WebService          *self,
 			   gpointer             soup_session_cb_data)
 {
 	if (self->priv->session == NULL) {
-		self->priv->session = soup_session_async_new_with_options (
-#ifdef HAVE_LIBSOUP_GNOME
-			SOUP_SESSION_ADD_FEATURE_BY_TYPE, SOUP_TYPE_PROXY_RESOLVER_GNOME,
-#endif
-			NULL);
+		self->priv->session = soup_session_new ();
 
 #ifdef DEBUG_WEB_CONNECTION
 		{
