@@ -39,6 +39,7 @@
 #define PICASA_WEB_REDIRECT_URI "urn:ietf:wg:oauth:2.0:oob"
 #define PICASA_WEB_REDIRECT_TITLE "Success code="
 #define PICASA_WEB_SERVICE_ERROR_TOKEN_EXPIRED 190
+#define PICASA_WEB_SERVICE_ERROR_UNAUTHORIZED 401
 #define GTHUMB_PICASA_WEB_CLIENT_ID "499958842898.apps.googleusercontent.com"
 #define GTHUMB_PICASA_WEB_CLIENT_SECRET "-DdIqzDxVRc_Wkobuf-2g-of"
 
@@ -87,6 +88,7 @@ struct _PicasaWebServicePrivate {
 	guint64         	 quota_limit;
 	guint64       		 quota_used;
 	PostPhotosData		*post_photos;
+	int                      n_auth_errors;
 };
 
 
@@ -174,6 +176,7 @@ picasa_web_utils_parse_json_response (SoupMessage  *msg,
 
 /* -- _picasa_web_service_get_refresh_token -- */
 
+
 static void
 _picasa_web_service_get_refresh_token_ready_cb (SoupSession *session,
 						SoupMessage *msg,
@@ -216,7 +219,7 @@ _picasa_web_service_get_refresh_token (PicasaWebService    *self,
 	g_hash_table_insert (data_set, "client_secret", GTHUMB_PICASA_WEB_CLIENT_SECRET);
 	g_hash_table_insert (data_set, "redirect_uri", PICASA_WEB_REDIRECT_URI);
 	g_hash_table_insert (data_set, "grant_type", "authorization_code");
-	msg = soup_form_request_new_from_hash ("POST", "https://accounts.google.com/o/oauth2/token", data_set);
+	msg = soup_form_request_new_from_hash ("POST", "https://www.googleapis.com/oauth2/v4/token", data_set);
 	_picasa_web_service_add_headers (self, msg);
 	_web_service_send_message (WEB_SERVICE (self),
 				   msg,
@@ -299,8 +302,9 @@ picasa_web_service_get_authorization_url (PicasaWebService *self)
 	g_hash_table_insert (data_set, "client_id", GTHUMB_PICASA_WEB_CLIENT_ID);
 	g_hash_table_insert (data_set, "redirect_uri", PICASA_WEB_REDIRECT_URI);
 	g_hash_table_insert (data_set, "scope", "https://picasaweb.google.com/data/ https://www.googleapis.com/auth/userinfo.profile");
+	g_hash_table_insert (data_set, "access_type", "offline");
 
-	link = g_string_new ("https://accounts.google.com/o/oauth2/auth?");
+	link = g_string_new ("https://accounts.google.com/o/oauth2/v2/auth?");
 	keys = g_hash_table_get_keys (data_set);
 	for (scan = keys; scan; scan = scan->next) {
 		char *key = scan->data;
@@ -424,40 +428,6 @@ _picasa_web_service_get_access_token_finish (PicasaWebService  *service,
 /* -- picasa_web_service_get_user_info -- */
 
 
-static void
-picasa_web_service_get_user_info_ready_cb (SoupSession *session,
-				           SoupMessage *msg,
-				           gpointer     user_data)
-{
-	PicasaWebService   *self = user_data;
-	GSimpleAsyncResult *result;
-	GError             *error = NULL;
-	JsonNode           *node;
-
-	result = _web_service_get_result (WEB_SERVICE (self));
-
-	if (picasa_web_utils_parse_json_response (msg, &node, &error)) {
-		OAuthAccount *account;
-
-		account = (OAuthAccount *) json_gobject_deserialize (OAUTH_TYPE_ACCOUNT, node);
-		g_object_set (account,
-			      "token", self->priv->access_token,
-			      "token-secret", self->priv->refresh_token,
-			      NULL);
-		g_simple_async_result_set_op_res_gpointer (result,
-							   g_object_ref (account),
-							   (GDestroyNotify) g_object_unref);
-
-		_g_object_unref (account);
-		json_node_free (node);
-	}
-	else
-		g_simple_async_result_set_from_error (result, error);
-
-	g_simple_async_result_complete_in_idle (result);
-}
-
-
 typedef struct {
 	PicasaWebService    *service;
 	GCancellable        *cancellable;
@@ -481,6 +451,65 @@ picasa_web_service_get_user_info (WebService          *base,
 				  gpointer	       user_data);
 
 
+static void
+picasa_web_service_get_user_info_ready_cb (SoupSession *session,
+				           SoupMessage *msg,
+				           gpointer     user_data)
+{
+	AccessTokenData    *data = user_data;
+	PicasaWebService   *self = data->service;
+	GSimpleAsyncResult *result;
+	GError             *error = NULL;
+	JsonNode           *node;
+
+	result = _web_service_get_result (WEB_SERVICE (self));
+
+	if (picasa_web_utils_parse_json_response (msg, &node, &error)) {
+		OAuthAccount *account;
+
+		account = (OAuthAccount *) json_gobject_deserialize (OAUTH_TYPE_ACCOUNT, node);
+		g_object_set (account,
+			      "token", self->priv->access_token,
+			      "token-secret", self->priv->refresh_token,
+			      NULL);
+		g_simple_async_result_set_op_res_gpointer (result,
+							   g_object_ref (account),
+							   (GDestroyNotify) g_object_unref);
+
+		_g_object_unref (account);
+		json_node_free (node);
+	}
+	else {
+		if (error->code == PICASA_WEB_SERVICE_ERROR_UNAUTHORIZED) {
+			self->priv->n_auth_errors += 1;
+			if (self->priv->n_auth_errors == 1) {
+				OAuthAccount *account;
+
+				/* reset the account token to force asking the
+				 * access token again. */
+
+				account = web_service_get_current_account (WEB_SERVICE (self));
+				if (account != NULL)
+					_g_strset (&account->token, NULL);
+
+				picasa_web_service_get_user_info (WEB_SERVICE (self),
+								  data->cancellable,
+								  data->callback,
+								  data->user_data);
+				access_token_data_free (data);
+				return;
+			}
+		}
+		g_simple_async_result_set_from_error (result, error);
+	}
+
+	self->priv->n_auth_errors = 0;
+	g_simple_async_result_complete_in_idle (result);
+
+	access_token_data_free (data);
+}
+
+
 static void
 access_token_ready_cb (GObject      *source_object,
 		       GAsyncResult *result,
@@ -493,6 +522,9 @@ access_token_ready_cb (GObject      *source_object,
 	if (! _picasa_web_service_get_access_token_finish (self, result, &error)) {
 		GSimpleAsyncResult *result;
 
+		if (error->code == PICASA_WEB_SERVICE_ERROR_UNAUTHORIZED)
+			self->priv->n_auth_errors += 1;
+
 		result = g_simple_async_result_new (G_OBJECT (self),
 						    data->callback,
 						    data->user_data,
@@ -522,8 +554,8 @@ picasa_web_service_get_user_info (WebService          *base,
 {
 	PicasaWebService *self = PICASA_WEB_SERVICE (base);
 	OAuthAccount     *account;
-	GHashTable       *data_set;
 	SoupMessage      *msg;
+	AccessTokenData  *data;
 
 	account = web_service_get_current_account (WEB_SERVICE (self));
 	if (account != NULL) {
@@ -531,8 +563,16 @@ picasa_web_service_get_user_info (WebService          *base,
 		_g_strset (&self->priv->access_token, account->token);
 	}
 
-	data_set = g_hash_table_new (g_str_hash, g_str_equal);
+	data = g_new0 (AccessTokenData, 1);
+	data->service = self;
+	data->cancellable = _g_object_ref (cancellable);
+	data->callback = callback;
+	data->user_data = user_data;
+
 	if (self->priv->access_token != NULL) {
+		GHashTable *data_set;
+
+		data_set = g_hash_table_new (g_str_hash, g_str_equal);
 		msg = soup_form_request_new_from_hash ("GET", "https://www.googleapis.com/oauth2/v2/userinfo", data_set);
 		_picasa_web_service_add_headers (self, msg);
 		_web_service_send_message (WEB_SERVICE (self),
@@ -542,26 +582,18 @@ picasa_web_service_get_user_info (WebService          *base,
 					   user_data,
 					   picasa_web_service_get_user_info,
 					   picasa_web_service_get_user_info_ready_cb,
-					   self);
+					   data);
+
+		g_hash_table_destroy (data_set);
 	}
 	else {
 		/* Get the access token from the refresh token */
-
-		AccessTokenData *data;
-
-		data = g_new0 (AccessTokenData, 1);
-		data->service = self;
-		data->cancellable = _g_object_ref (cancellable);
-		data->callback = callback;
-		data->user_data = user_data;
 		_picasa_web_service_get_access_token (self,
 						      self->priv->refresh_token,
 						      cancellable,
 						      access_token_ready_cb,
 						      data);
 	}
-
-	g_hash_table_destroy (data_set);
 }
 
 
@@ -591,6 +623,7 @@ picasa_web_service_init (PicasaWebService *self)
 	self->priv->quota_limit = 0;
 	self->priv->quota_used = 0;
 	self->priv->post_photos = NULL;
+	self->priv->n_auth_errors = 0;
 }
 
 
@@ -738,107 +771,6 @@ picasa_web_service_list_albums_finish (PicasaWebService  *service,
 }
 
 
-/* -- picasa_web_service_create_album -- */
-
-
-static void
-create_album_ready_cb (SoupSession *session,
-		       SoupMessage *msg,
-		       gpointer     user_data)
-{
-	PicasaWebService   *self = user_data;
-	GSimpleAsyncResult *result;
-	SoupBuffer         *body;
-	DomDocument        *doc;
-	GError             *error = NULL;
-
-	result = _web_service_get_result (WEB_SERVICE (self));
-
-	if (msg->status_code != 201) {
-		g_simple_async_result_set_error (result,
-						 SOUP_HTTP_ERROR,
-						 msg->status_code,
-						 "%s",
-						 soup_status_get_phrase (msg->status_code));
-		g_simple_async_result_complete_in_idle (result);
-		return;
-	}
-
-	body = soup_message_body_flatten (msg->response_body);
-	doc = dom_document_new ();
-	if (dom_document_load (doc, body->data, body->length, &error)) {
-		PicasaWebAlbum *album;
-
-		album = picasa_web_album_new ();
-		dom_domizable_load_from_element (DOM_DOMIZABLE (album), DOM_ELEMENT (doc)->first_child);
-		g_simple_async_result_set_op_res_gpointer (result, album, (GDestroyNotify) g_object_unref);
-	}
-	else {
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-	}
-	g_simple_async_result_complete_in_idle (result);
-
-	g_object_unref (doc);
-	soup_buffer_free (body);
-}
-
-
-void
-picasa_web_service_create_album (PicasaWebService     *self,
-				 PicasaWebAlbum       *album,
-				 GCancellable         *cancellable,
-				 GAsyncReadyCallback   callback,
-				 gpointer              user_data)
-{
-	OAuthAccount *account;
-	DomDocument  *doc;
-	DomElement   *entry;
-	char         *buffer;
-	gsize         len;
-	char         *url;
-	SoupMessage  *msg;
-
-	account = web_service_get_current_account (WEB_SERVICE (self));
-	g_return_if_fail (account != NULL);
-
-	gth_task_progress (GTH_TASK (self), _("Creating the new album"), NULL, TRUE, 0.0);
-
-	doc = dom_document_new ();
-	entry = dom_domizable_create_element (DOM_DOMIZABLE (album), doc);
-	dom_element_append_child (DOM_ELEMENT (doc), entry);
-	buffer = dom_document_dump (doc, &len);
-
-	url = g_strconcat ("https://picasaweb.google.com/data/feed/api/user/", account->id, NULL);
-	msg = soup_message_new ("POST", url);
-	soup_message_set_request (msg, ATOM_ENTRY_MIME_TYPE, SOUP_MEMORY_TAKE, buffer, len);
-	_picasa_web_service_add_headers (self, msg);
-	_web_service_send_message (WEB_SERVICE (self),
-				   msg,
-				   cancellable,
-				   callback,
-				   user_data,
-				   picasa_web_service_create_album,
-				   create_album_ready_cb,
-				   self);
-
-	g_free (url);
-	g_object_unref (doc);
-}
-
-
-PicasaWebAlbum *
-picasa_web_service_create_album_finish (PicasaWebService  *service,
-					GAsyncResult      *result,
-					GError           **error)
-{
-	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error))
-		return NULL;
-	else
-		return g_object_ref (g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result)));
-}
-
-
 /* -- picasa_web_service_post_photos -- */
 
 
