@@ -165,6 +165,8 @@ gth_template_editor_dialog_construct (GthTemplateEditorDialog *self,
 	gtk_dialog_add_button (GTK_DIALOG (self), _GTK_LABEL_CANCEL, GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (self), _GTK_LABEL_OK, GTK_RESPONSE_OK);
 
+	_gtk_dialog_add_class_to_response (GTK_DIALOG (self), GTK_RESPONSE_OK, GTK_STYLE_CLASS_SUGGESTED_ACTION);
+
     	self->priv->content = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     	gtk_container_set_border_width (GTK_CONTAINER (self->priv->content), 5);
     	gtk_widget_show (self->priv->content);
@@ -234,7 +236,9 @@ gth_template_editor_dialog_new (GthTemplateCode *allowed_codes,
 {
 	GthTemplateEditorDialog *self;
 
-	self = g_object_new (GTH_TYPE_TEMPLATE_EDITOR_DIALOG, NULL);
+	self = g_object_new (GTH_TYPE_TEMPLATE_EDITOR_DIALOG,
+			     "use-header-bar", _gtk_settings_get_dialogs_use_header (),
+			     NULL);
 	gth_template_editor_dialog_construct (self, allowed_codes, n_codes, title, parent);
 
 	return (GtkWidget *) self;
