@@ -160,13 +160,6 @@ folder_changed_cb (GthMonitor      *monitor,
 }
 
 
-void
-selections__initialize_cb (void)
-{
-	gth_selections_manager_load_from_file ();
-}
-
-
 void
 selections__gth_browser_construct_cb (GthBrowser *browser)
 {
@@ -199,13 +192,6 @@ selections__gth_browser_construct_cb (GthBrowser *browser)
 }
 
 
-void
-selections__gth_browser_close_last_window_cb (GthBrowser *browser)
-{
-	gth_selections_manager_save_to_file ();
-}
-
-
 void
 selections__gth_browser_update_sensitivity_cb (GthBrowser *browser)
 {
