@@ -1035,6 +1035,8 @@ header_footer_eval_cb (const GMatchInfo *match_info,
 		a = g_regex_split (re, match, 0);
 		if (g_strv_length (a) >= 2)
 			format = g_strstrip (a[1]);
+		else
+			format = DEFAULT_DATE_FORMAT;
 		r = _g_time_val_strftime (&timeval, format);
 
 		g_strfreev (a);
@@ -1951,7 +1953,7 @@ save_other_files_ready_cb (GError   *error,
 		_g_copy_files_async (files,
 				     self->priv->target_dir,
 				     FALSE,
-				     G_FILE_COPY_NONE,
+				     GTH_FILE_COPY_DEFAULT,
 				     GTH_OVERWRITE_RESPONSE_UNSPECIFIED,
 				     G_PRIORITY_DEFAULT,
 				     gth_task_get_cancellable (GTH_TASK (self)),
@@ -2026,7 +2028,7 @@ save_other_files (GthWebExporter *self)
 		_g_copy_files_async (files,
 				     theme_dir,
 				     FALSE,
-				     G_FILE_COPY_NONE,
+				     GTH_FILE_COPY_DEFAULT,
 				     GTH_OVERWRITE_RESPONSE_UNSPECIFIED,
 				     G_PRIORITY_DEFAULT,
 				     gth_task_get_cancellable (GTH_TASK (self)),
@@ -2601,7 +2603,7 @@ image_loader_ready_cb (GObject      *source_object,
 			scaled = _cairo_image_surface_scale (surface, w, h, SCALE_FILTER_BEST, NULL);
 			idata->image = gth_image_new_for_surface (scaled);
 			idata->image_width = cairo_image_surface_get_width (scaled);
-			idata->image_height = cairo_image_surface_get_width (scaled);
+			idata->image_height = cairo_image_surface_get_height (scaled);
 
 			cairo_surface_destroy (scaled);
 		}
@@ -2631,7 +2633,7 @@ image_loader_ready_cb (GObject      *source_object,
 			scaled = _cairo_image_surface_scale (surface, w, h, SCALE_FILTER_BEST, NULL);
 			idata->preview = gth_image_new_for_surface (scaled);
 			idata->preview_width = cairo_image_surface_get_width (scaled);
-			idata->preview_height = cairo_image_surface_get_width (scaled);
+			idata->preview_height = cairo_image_surface_get_height (scaled);
 
 			cairo_surface_destroy (scaled);
 		}
@@ -2663,7 +2665,7 @@ image_loader_ready_cb (GObject      *source_object,
 			scaled = _cairo_image_surface_scale_squared (surface, self->priv->thumb_width, SCALE_FILTER_BEST, NULL);
 			idata->thumb = gth_image_new_for_surface (scaled);
 			idata->thumb_width = cairo_image_surface_get_width (scaled);
-			idata->thumb_height = cairo_image_surface_get_width (scaled);
+			idata->thumb_height = cairo_image_surface_get_height (scaled);
 
 			cairo_surface_destroy (scaled);
 		}
@@ -2679,7 +2681,7 @@ image_loader_ready_cb (GObject      *source_object,
 			scaled = _cairo_image_surface_scale (surface, w, h, SCALE_FILTER_BEST, NULL);
 			idata->thumb = gth_image_new_for_surface (scaled);
 			idata->thumb_width = cairo_image_surface_get_width (scaled);
-			idata->thumb_height = cairo_image_surface_get_width (scaled);
+			idata->thumb_height = cairo_image_surface_get_height (scaled);
 
 			cairo_surface_destroy (scaled);
 		}
