@@ -197,7 +197,7 @@ ok_button_clicked_cb (GtkWidget  *widget,
 	if (uri == NULL) {
 		char *title;
 
-		title = g_strdup_printf (_("Could not load the position \"%s\""), gtk_entry_get_text (GTK_ENTRY (GET_WIDGET ("location_entry"))));
+		title = g_strdup_printf (_("Could not load the position “%s”"), gtk_entry_get_text (GTK_ENTRY (GET_WIDGET ("location_entry"))));
 		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (GET_WIDGET ("location_dialog")), title, error);
 
 		g_free (title);
@@ -418,7 +418,7 @@ dlg_location (GthBrowser *browser)
 				_("Open"), GTK_RESPONSE_OK,
 				NULL);
 	_gtk_dialog_add_class_to_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK, GTK_STYLE_CLASS_SUGGESTED_ACTION);
-
+	gtk_widget_grab_default (gtk_dialog_get_widget_for_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK));
 	gth_browser_set_dialog (browser, "location", data->dialog);
 
 	/* set the widget data */
