@@ -25,9 +25,6 @@
 #include "typedefs.h"
 
 
-#define PROGRESS_DELAY 100 /* delay between progress notifications */
-
-
 /* Properties */
 enum {
         PROP_0,
@@ -50,6 +47,7 @@ struct _GthAsyncTaskPrivate {
 	gboolean            cancelled;
 	gboolean            terminated;
 	double              progress;
+	GThread            *thread;
 };
 
 
@@ -106,6 +104,9 @@ update_progress (gpointer data)
 	if (terminated) {
 		GError *error = NULL;
 
+		g_thread_join (self->priv->thread);
+		self->priv->thread = NULL;
+
 		g_source_remove (self->priv->progress_event);
 		self->priv->progress_event = 0;
 
@@ -119,7 +120,7 @@ update_progress (gpointer data)
 
 		ready_with_error (task_completed, self, error);
 
-		return FALSE;
+		return G_SOURCE_REMOVE;
 	}
 
 	gth_task_progress (GTH_TASK (self),
@@ -128,7 +129,7 @@ update_progress (gpointer data)
 			   FALSE,
 			   progress);
 
-	return TRUE;
+	return G_SOURCE_CONTINUE;
 }
 
 
@@ -162,10 +163,10 @@ gth_async_task_exec (GthTask *task)
 
 	if (self->priv->before_func != NULL)
 		self->priv->before_func (self, self->priv->user_data);
-	g_thread_new ("gth_async_task_exec", exec_task, self);
+	self->priv->thread = g_thread_new ("asynctask", exec_task, self);
 
 	if (self->priv->progress_event == 0)
-		self->priv->progress_event = g_timeout_add (PROGRESS_DELAY, update_progress, self);
+		self->priv->progress_event = g_idle_add (update_progress, self);
 }
 
 
