@@ -24,7 +24,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include "glib-utils.h"
-#include "gth-dumb-notebook.h"
 #include "gth-empty-list.h"
 #include "gth-file-list.h"
 #include "gth-file-selection.h"
@@ -42,6 +41,8 @@
 #define N_CREATEAHEAD 50000
 #define EMPTY (N_("(Empty)"))
 #define CHECK_JOBS_INTERVAL 50
+#define _FILE_VIEW "file-view"
+#define _EMPTY_VIEW "empty-view"
 
 
 typedef enum {
@@ -101,12 +102,6 @@ typedef struct {
 } ThumbnailJob;
 
 
-enum {
-	GTH_FILE_LIST_PANE_VIEW,
-	GTH_FILE_LIST_PANE_MESSAGE
-};
-
-
 typedef enum {
 	THUMBNAILER_PHASE_INITIALIZE,
 	THUMBNAILER_PHASE_UPDATE_VISIBLE,
@@ -361,15 +356,6 @@ gth_file_list_get_preferred_height (GtkWidget *widget,
 }
 
 
-static void
-gth_file_list_grab_focus (GtkWidget *widget)
-{
-	GthFileList *file_list = GTH_FILE_LIST (widget);
-
-	gtk_widget_grab_focus (file_list->priv->notebook);
-}
-
-
 static void
 gth_file_list_class_init (GthFileListClass *class)
 {
@@ -383,7 +369,6 @@ gth_file_list_class_init (GthFileListClass *class)
 	widget_class->get_request_mode = gth_file_list_get_request_mode;
 	widget_class->get_preferred_width = gth_file_list_get_preferred_width;
 	widget_class->get_preferred_height = gth_file_list_get_preferred_height;
-	widget_class->grab_focus = gth_file_list_grab_focus;
 }
 
 
@@ -427,6 +412,8 @@ thumb_data_unref (ThumbData *data)
 static void
 gth_file_list_init (GthFileList *file_list)
 {
+	gtk_widget_set_can_focus (GTK_WIDGET (file_list), FALSE);
+
 	file_list->priv = g_new0 (GthFileListPrivateData, 1);
 	file_list->priv->settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
 	file_list->priv->thumb_data = g_hash_table_new_full (g_file_hash, (GEqualFunc) g_file_equal, g_object_unref, (GDestroyNotify) thumb_data_unref);
@@ -629,7 +616,8 @@ gth_file_list_construct (GthFileList     *file_list,
 
 	/* the main notebook */
 
-	file_list->priv->notebook = gth_dumb_notebook_new ();
+	file_list->priv->notebook = gtk_stack_new ();
+	gtk_widget_set_can_focus (file_list->priv->notebook, FALSE);
 
 	/* the message pane */
 
@@ -638,6 +626,7 @@ gth_file_list_construct (GthFileList     *file_list,
 	/* the file view */
 
 	file_list->priv->scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+	gtk_widget_set_can_focus (file_list->priv->scrolled_window, FALSE);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window), GTK_SHADOW_ETCHED_IN);
 
 	file_list->priv->vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window));
@@ -679,15 +668,15 @@ gth_file_list_construct (GthFileList     *file_list,
 	gtk_container_add (GTK_CONTAINER (file_list->priv->scrolled_window), file_list->priv->view);
 
 	gtk_widget_show (file_list->priv->scrolled_window);
-	gtk_container_add (GTK_CONTAINER (file_list->priv->notebook), file_list->priv->scrolled_window);
+	gtk_stack_add_named (GTK_STACK (file_list->priv->notebook), file_list->priv->scrolled_window, _FILE_VIEW);
 
 	gtk_widget_show (file_list->priv->message);
-	gtk_container_add (GTK_CONTAINER (file_list->priv->notebook), file_list->priv->message);
+	gtk_stack_add_named (GTK_STACK (file_list->priv->notebook), file_list->priv->message, _EMPTY_VIEW);
 
 	gtk_widget_show (file_list->priv->notebook);
 	gtk_box_pack_start (GTK_BOX (file_list), file_list->priv->notebook, TRUE, TRUE, 0);
 
-	gth_dumb_notebook_show_child (GTH_DUMB_NOTEBOOK (file_list->priv->notebook), GTH_FILE_LIST_PANE_MESSAGE);
+	gtk_stack_set_visible_child_name (GTK_STACK (file_list->priv->notebook), _EMPTY_VIEW);
 }
 
 
@@ -833,7 +822,7 @@ gfl_clear_list (GthFileList *file_list,
 	g_hash_table_remove_all (file_list->priv->thumb_data);
 
 	gth_empty_list_set_text (GTH_EMPTY_LIST (file_list->priv->message), message);
-	gth_dumb_notebook_show_child (GTH_DUMB_NOTEBOOK (file_list->priv->notebook), GTH_FILE_LIST_PANE_MESSAGE);
+	gtk_stack_set_visible_child_name (GTK_STACK (file_list->priv->notebook), _EMPTY_VIEW);
 }
 
 
@@ -857,11 +846,11 @@ _gth_file_list_update_pane (GthFileList *file_list)
 	file_store = (GthFileStore*) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view));
 
 	if (gth_file_store_n_visibles (file_store) > 0) {
-		gth_dumb_notebook_show_child (GTH_DUMB_NOTEBOOK (file_list->priv->notebook), GTH_FILE_LIST_PANE_VIEW);
+		gtk_stack_set_visible_child_name (GTK_STACK (file_list->priv->notebook), _FILE_VIEW);
 	}
 	else {
 		gth_empty_list_set_text (GTH_EMPTY_LIST (file_list->priv->message), _(EMPTY));
-		gth_dumb_notebook_show_child (GTH_DUMB_NOTEBOOK (file_list->priv->notebook), GTH_FILE_LIST_PANE_MESSAGE);
+		gtk_stack_set_visible_child_name (GTK_STACK (file_list->priv->notebook), _EMPTY_VIEW);
 	}
 }
 
@@ -2166,3 +2155,15 @@ gth_file_list_unset_drag_source (GthFileList *file_list)
 {
 	gth_file_view_unset_drag_source (GTH_FILE_VIEW (file_list->priv->view));
 }
+
+
+void
+gth_file_list_focus (GthFileList *file_list)
+{
+	GtkWidget *child;
+
+	child = gtk_stack_get_visible_child (GTK_STACK (file_list->priv->notebook));
+	if (GTK_IS_BIN (child))
+		child = gtk_bin_get_child (GTK_BIN (child));
+	gtk_widget_grab_focus ((child != NULL) ? child : GTK_WIDGET (file_list));
+}
