@@ -197,6 +197,30 @@ _gth_file_store_free_rows (GthFileStore *file_store)
 }
 
 
+#ifdef DEBUG_FILE_STORE
+
+static void
+_print_rows (GthFileRow **rows, int n, char *info)
+{
+	int i;
+
+	g_print ("%s\n", info);
+	for (i = 0; i < n; i++) {
+		GthFileRow *row = rows[i];
+		g_print ("(%d) [%d] %s\n", i, row->pos, g_file_get_uri (row->file_data->file));
+	}
+}
+
+
+static void
+_gth_file_store_print (GthFileStore *file_store, char *info)
+{
+	_print_rows (file_store->priv->rows, file_store->priv->num_rows, info);
+}
+
+#endif
+
+
 static void
 gth_file_store_finalize (GObject *object)
 {
@@ -661,7 +685,7 @@ _gth_file_store_get_files (GthFileStore *file_store)
 
 
 static int
-campare_row_func (gconstpointer a,
+compare_row_func (gconstpointer a,
 		  gconstpointer b,
 		  gpointer      user_data)
 {
@@ -671,11 +695,9 @@ campare_row_func (gconstpointer a,
 	int           result;
 
 	if (file_store->priv->cmp_func == NULL)
-		result = -1 /*strcmp (gth_file_data_get_filename_sort_key (row_a->file),
-			       gth_file_data_get_filename_sort_key (row_b->file))*/;
-	else
-		result = file_store->priv->cmp_func (row_a->file_data, row_b->file_data);
+		return -1;
 
+	result = file_store->priv->cmp_func (row_a->file_data, row_b->file_data);
 	if (file_store->priv->inverse_sort)
 		result = result * -1;
 
@@ -694,13 +716,13 @@ _gth_file_store_sort (GthFileStore *file_store,
 	g_qsort_with_data (pbase,
 			   total_elems,
 			   (gsize) sizeof (GthFileRow *),
-			   campare_row_func,
+			   compare_row_func,
 			   file_store);
 }
 
 
 static int
-campare_by_pos (gconstpointer a,
+compare_by_pos (gconstpointer a,
 		gconstpointer b,
 		gpointer      user_data)
 {
@@ -728,14 +750,6 @@ _gth_file_store_compact_rows (GthFileStore *file_store)
 			j++;
 		}
 	file_store->priv->tot_rows = j;
-
-	for (i = 0, j = 0; i < file_store->priv->num_rows; i++)
-		if (file_store->priv->rows[i] != NULL) {
-			file_store->priv->rows[j] = file_store->priv->rows[i];
-			file_store->priv->rows[j]->pos = j;
-			j++;
-		}
-	file_store->priv->num_rows = j;
 }
 
 
@@ -766,6 +780,7 @@ _gth_file_store_update_visibility (GthFileStore *file_store,
 {
 	GthFileRow **all_rows = NULL;
 	guint        all_rows_n = 0;
+	int          add_queue_size;
 	GthFileRow **old_rows = NULL;
 	guint        old_rows_n = 0;
 	GthFileRow **new_rows = NULL;
@@ -779,14 +794,14 @@ _gth_file_store_update_visibility (GthFileStore *file_store,
 	gboolean     row_deleted;
 	GHashTable  *new_rows_index;
 
-
 #ifdef DEBUG_FILE_STORE
 g_print ("UPDATE VISIBILITY\n");
 #endif
 
 	/* store the current state */
 
-	all_rows_n = file_store->priv->tot_rows + g_list_length (add_queue);
+	add_queue_size = g_list_length (add_queue);
+	all_rows_n = file_store->priv->tot_rows + add_queue_size;
 	all_rows = g_new (GthFileRow *, all_rows_n);
 
 	/* append to the end if position is -1 */
@@ -797,12 +812,21 @@ g_print ("UPDATE VISIBILITY\n");
 	/* insert the new rows at position */
 
 	j = 0;
-	for (i = 0; i < position; i++)
-		all_rows[j++] = _gth_file_row_copy (file_store->priv->all_rows[i]);
-	for (scan = add_queue; scan; scan = scan->next)
-		all_rows[j++] = _gth_file_row_ref ((GthFileRow *) scan->data);
-	for (i = position; i < file_store->priv->tot_rows; i++)
-		all_rows[j++] = _gth_file_row_copy (file_store->priv->all_rows[i]);
+	for (i = 0; i < file_store->priv->tot_rows; i++) {
+		all_rows[j] = _gth_file_row_copy (file_store->priv->all_rows[i]);
+		if (all_rows[j]->visible && (all_rows[j]->pos >= position))
+			all_rows[j]->pos += add_queue_size;
+		j++;
+	}
+
+	for (scan = add_queue; scan; scan = scan->next) {
+		all_rows[j] = _gth_file_row_ref ((GthFileRow *) scan->data);
+		all_rows[j]->pos = position++;
+		j++;
+	}
+
+	/* old_rows is equal to file_store->priv->rows but points to
+	 * the rows of all_rows */
 
 	old_rows_n = file_store->priv->num_rows;
 	old_rows = g_new (GthFileRow *, old_rows_n);
@@ -814,9 +838,24 @@ g_print ("UPDATE VISIBILITY\n");
 		}
 	}
 
-	/* reorder and filter */
+	/* make sure old_rows preserve the order of the visible rows, sorting by
+	 * position (compare_by_pos) */
 
-	_gth_file_store_sort (file_store, all_rows, all_rows_n);
+	g_qsort_with_data (old_rows,
+			   old_rows_n,
+			   (gsize) sizeof (GthFileRow *),
+			   compare_by_pos,
+			   file_store);
+
+	/* sort */
+
+	g_qsort_with_data (all_rows,
+			   all_rows_n,
+			   (gsize) sizeof (GthFileRow *),
+			   (file_store->priv->cmp_func != NULL) ? compare_row_func : compare_by_pos,
+			   file_store);
+
+	/* filter */
 
 	/* store the new_rows file positions in an hash table for
 	 * faster searching. */
@@ -991,7 +1030,7 @@ g_print ("\n");
 	g_qsort_with_data (old_rows,
 			   old_rows_n,
 			   (gsize) sizeof (GthFileRow *),
-			   campare_by_pos,
+			   compare_by_pos,
 			   NULL);
 
 	g_free (file_store->priv->rows);
@@ -1374,6 +1413,7 @@ void
 gth_file_store_exec_add (GthFileStore *file_store,
 			 int           position)
 {
+	file_store->priv->queue = g_list_reverse (file_store->priv->queue);
 	_gth_file_store_update_visibility (file_store, file_store->priv->queue, position);
 	_gth_file_store_clear_queue (file_store);
 }
@@ -1616,50 +1656,20 @@ gth_file_store_clear (GthFileStore *file_store)
 }
 
 
-static int
-reorder_sort_func (gconstpointer a,
-		   gconstpointer b,
-		   gpointer      user_data)
-{
-	GHashTable *new_positions = user_data;
-	int         apos = GPOINTER_TO_INT (g_hash_table_lookup (new_positions, * (GthFileRow **) a));
-	int         bpos = GPOINTER_TO_INT (g_hash_table_lookup (new_positions, * (GthFileRow **) b));
-
-	if (apos < bpos)
-		return -1;
-	if (apos > bpos)
-		return 1;
-	return 0;
-}
-
-
 void
 gth_file_store_reorder (GthFileStore *file_store,
 			int          *new_order)
 {
-	int         *order;
-	GHashTable  *new_positions;
-	int          i;
+	int i;
 
-	order = g_new (int, file_store->priv->num_rows);
 	for (i = 0; i < file_store->priv->num_rows; i++)
-		order[new_order[i]] = i;
-
-	new_positions = g_hash_table_new (g_direct_hash, g_direct_equal);
-	for (i = 0; i < file_store->priv->num_rows; i++)
-		g_hash_table_insert (new_positions, file_store->priv->rows[i], GINT_TO_POINTER (order[i]));
+		file_store->priv->rows[new_order[i]]->pos = i;
 
 	g_qsort_with_data (file_store->priv->rows,
 			   file_store->priv->num_rows,
 			   (gsize) sizeof (GthFileRow *),
-			   reorder_sort_func,
-			   new_positions);
-
-	for (i = 0; i < file_store->priv->num_rows; i++)
-		file_store->priv->rows[i]->pos = i;
+			   compare_by_pos,
+			   NULL);
 
 	gtk_tree_model_rows_reordered (GTK_TREE_MODEL (file_store), NULL, NULL, new_order);
-
-	g_hash_table_destroy (new_positions);
-	g_free (order);
 }
