@@ -281,6 +281,7 @@ gth_image_dragger_draw (GthImageViewerTool *self,
 	}
 	else {
 		double zoom = gth_image_viewer_get_zoom (viewer);
+		int    screen_scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (viewer));
 
 		gth_image_viewer_paint_region (viewer,
 					       cr,
@@ -288,7 +289,7 @@ gth_image_dragger_draw (GthImageViewerTool *self,
 					       viewer->image_area.x,
 					       viewer->image_area.y,
 					       &viewer->visible_area,
-					       (gth_image_viewer_get_zoom_quality (viewer) == GTH_ZOOM_QUALITY_HIGH) && (zoom > 1.0) && (zoom <= MAX_ZOOM_LEVEL_FOR_HIGH_QUALITY) ? CAIRO_FILTER_BILINEAR : CAIRO_FILTER_FAST);
+					       (gth_image_viewer_get_zoom_quality (viewer) == GTH_ZOOM_QUALITY_HIGH) && (zoom * screen_scale_factor > 1.0) && (zoom <= MAX_ZOOM_LEVEL_FOR_HIGH_QUALITY) ? CAIRO_FILTER_BILINEAR : CAIRO_FILTER_FAST);
 	}
 
 	gth_image_viewer_apply_painters (viewer, cr);
@@ -493,6 +494,7 @@ _gth_image_dragger_update_scaled_image (GthImageDragger *self)
 	int              image_width, image_height;
 	int              original_width, original_height;
 	int              new_width, new_height;
+	int              screen_scale_factor;
 	scale_filter_t   filter;
 
 	self->priv->scaled_zoom = 0;
@@ -517,6 +519,8 @@ _gth_image_dragger_update_scaled_image (GthImageDragger *self)
 		return;
 	}
 
+	screen_scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (self->priv->viewer));
+
 	if (gth_image_viewer_get_zoom_quality_filter (self->priv->viewer) == CAIRO_FILTER_FAST) {
 		gtk_widget_queue_draw (GTK_WIDGET (self->priv->viewer));
 		return;
@@ -524,8 +528,8 @@ _gth_image_dragger_update_scaled_image (GthImageDragger *self)
 
 	zoom_from_original = gth_image_viewer_get_zoom (self->priv->viewer);
 	gth_image_viewer_get_original_size (self->priv->viewer, &original_width, &original_height);
-	new_width = zoom_from_original * original_width;
-	new_height = zoom_from_original * original_height;
+	new_width = zoom_from_original * original_width * screen_scale_factor;
+	new_height = zoom_from_original * original_height * screen_scale_factor;
 	image_width = cairo_image_surface_get_width (image);
 	image_height = cairo_image_surface_get_height (image);
 	zoom_from_image = (double) new_width / image_width;
