@@ -30,91 +30,10 @@
 #include "cairo-utils.h"
 #include "glib-utils.h"
 #include "gth-image.h"
+#include "gth-main.h"
 #include "pixbuf-utils.h"
 
 
-/* -- GthICCData -- */
-
-
-#define GTH_TYPE_ICC_DATA            (gth_icc_data_get_type ())
-#define GTH_ICC_DATA(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTH_TYPE_ICC_DATA, GthICCData))
-#define GTH_ICC_DATA_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GTH_TYPE_ICC_DATA, GthICCDataClass))
-#define GTH_IS_ICC_DATA(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTH_TYPE_ICC_DATA))
-#define GTH_IS_ICC_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTH_TYPE_ICC_DATA))
-#define GTH_ICC_DATA_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), GTH_TYPE_ICC_DATA, GthICCDataClass))
-
-typedef struct _GthICCData         GthICCData;
-typedef struct _GthICCDataClass    GthICCDataClass;
-
-struct _GthICCData {
-	GObject __parent;
-	GthICCProfile icc_profile;
-};
-
-struct _GthICCDataClass {
-	GObjectClass __parent_class;
-};
-
-
-static GType gth_icc_data_get_type (void);
-
-
-G_DEFINE_TYPE (GthICCData, gth_icc_data, G_TYPE_OBJECT)
-
-
-static void
-gth_icc_data_finalize (GObject *object)
-{
-	GthICCData *icc_data;
-
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (GTH_IS_ICC_DATA (object));
-
-	icc_data = GTH_ICC_DATA (object);
-	gth_icc_profile_free (icc_data->icc_profile);
-
-	/* Chain up */
-	G_OBJECT_CLASS (gth_icc_data_parent_class)->finalize (object);
-}
-
-
-static void
-gth_icc_data_class_init (GthICCDataClass *klass)
-{
-	GObjectClass *gobject_class;
-
-	gobject_class = (GObjectClass*) klass;
-	gobject_class->finalize = gth_icc_data_finalize;
-}
-
-
-static void
-gth_icc_data_init (GthICCData *self)
-{
-	self->icc_profile = NULL;
-}
-
-
-static GthICCData *
-gth_icc_data_new (GthICCProfile profile)
-{
-	GthICCData *icc_data;
-
-	icc_data = g_object_new (GTH_TYPE_ICC_DATA, NULL);
-	icc_data->icc_profile = profile;
-
-	return icc_data;
-}
-
-
-static GthICCProfile
-gth_icc_data_get_profile (GthICCData *self)
-{
-	g_return_val_if_fail (self != NULL, NULL);
-	return self->icc_profile;
-}
-
-
 /* -- GthImage -- */
 
 
@@ -125,7 +44,7 @@ struct _GthImagePrivate {
 		GdkPixbuf          *pixbuf;
 		GdkPixbufAnimation *pixbuf_animation;
 	} data;
-	GthICCData *icc_data;
+	GthICCProfile *icc_data;
 };
 
 
@@ -502,55 +421,42 @@ gth_image_get_is_animation (GthImage *image)
 
 
 void
-gth_image_set_icc_profile (GthImage	 *image,
-			   GthICCProfile  profile)
+gth_image_set_icc_profile (GthImage   *image,
+			   GthICCProfile *profile)
 {
+	_g_object_ref (profile);
 	_gth_image_free_icc_profile (image);
-	if (profile != NULL)
-		image->priv->icc_data = gth_icc_data_new (profile);
+	image->priv->icc_data = profile;
 }
 
 
-GthICCProfile
+GthICCProfile *
 gth_image_get_icc_profile (GthImage *image)
 {
 	g_return_val_if_fail (image != NULL, NULL);
-	return (image->priv->icc_data != NULL) ? gth_icc_data_get_profile (image->priv->icc_data) : NULL;
+	return image->priv->icc_data;
 }
 
 
 /* -- gth_image_apply_icc_profile -- */
 
 
-#if HAVE_LCMS2
-#if G_BYTE_ORDER == G_LITTLE_ENDIAN /* BGRA */
-#define _LCMS2_CAIRO_FORMAT TYPE_BGRA_8
-#elif G_BYTE_ORDER == G_BIG_ENDIAN /* ARGB */
-#define _LCMS2_CAIRO_FORMAT TYPE_ARGB_8
-#else
-#define _LCMS2_CAIRO_FORMAT TYPE_ABGR_8
-#endif
-#endif
-
-
 void
 gth_image_apply_icc_profile (GthImage      *image,
-			     GthICCProfile  out_profile,
+			     GthICCProfile *out_profile,
 			     GCancellable  *cancellable)
 {
 #if HAVE_LCMS2
 
-	GthICCProfile    image_profile;
-	cmsHTRANSFORM    hTransform;
 	cairo_surface_t *surface;
+	GthICCTransform *transform;
 
 	g_return_if_fail (image != NULL);
 
 	if (out_profile == NULL)
 		return;
 
-	image_profile = gth_image_get_icc_profile (image);
-	if (image_profile == NULL)
+	if (image->priv->icc_data == NULL)
 		return;
 
 	if (image->priv->format != GTH_IMAGE_FORMAT_CAIRO_SURFACE)
@@ -560,19 +466,19 @@ gth_image_apply_icc_profile (GthImage      *image,
 	if (surface == NULL)
 		return;
 
-	hTransform = cmsCreateTransform ((cmsHPROFILE) image_profile,
-					 _LCMS2_CAIRO_FORMAT,
-					 (cmsHPROFILE) out_profile,
-					 _LCMS2_CAIRO_FORMAT,
-					 INTENT_PERCEPTUAL, 0);
+	transform = gth_color_manager_get_transform (gth_main_get_default_color_manager (),
+			      	      	      	     image->priv->icc_data,
+						     out_profile);
 
-	if (hTransform != NULL) {
+	if (transform != NULL) {
+		cmsHTRANSFORM    hTransform;
 		unsigned char   *surface_row;
 		int              width;
 		int              height;
 		int              row_stride;
 		int              row;
 
+		hTransform = (cmsHTRANSFORM) gth_icc_transform_get_transform (transform);
 		surface_row = _cairo_image_surface_flush_and_get_data (surface);
 		width = cairo_image_surface_get_width (surface);
 		height = cairo_image_surface_get_height (surface);
@@ -587,9 +493,10 @@ gth_image_apply_icc_profile (GthImage      *image,
 		cairo_surface_mark_dirty (surface);
 
 		cairo_surface_destroy (surface);
-		cmsDeleteTransform (hTransform);
 	}
 
+	_g_object_unref (transform);
+
 #endif
 }
 
@@ -598,8 +505,8 @@ gth_image_apply_icc_profile (GthImage      *image,
 
 
 typedef struct {
-	GthImage	*image;
-	GthICCProfile	 out_profile;
+	GthImage   *image;
+	GthICCProfile *out_profile;
 } ApplyProfileData;
 
 
@@ -609,6 +516,7 @@ apply_profile_data_free (gpointer user_data)
 	ApplyProfileData *apd = user_data;
 
 	g_object_unref (apd->image);
+	_g_object_unref (apd->out_profile);
 	g_free (apd);
 }
 
@@ -636,7 +544,7 @@ _gth_image_apply_icc_profile_thread (GSimpleAsyncResult *result,
 
 void
 gth_image_apply_icc_profile_async (GthImage		*image,
-				   GthICCProfile	 out_profile,
+				   GthICCProfile	*out_profile,
 				   GCancellable		*cancellable,
 				   GAsyncReadyCallback	 callback,
 				   gpointer		 user_data)
@@ -653,7 +561,7 @@ gth_image_apply_icc_profile_async (GthImage		*image,
 
 	apd = g_new (ApplyProfileData, 1);
 	apd->image = g_object_ref (image);
-	apd->out_profile = out_profile;
+	apd->out_profile = _g_object_ref (out_profile);
 	g_simple_async_result_set_op_res_gpointer (result, apd, apply_profile_data_free);
 	g_simple_async_result_run_in_thread (result,
 	                                     _gth_image_apply_icc_profile_thread,
@@ -671,13 +579,3 @@ gth_image_apply_icc_profile_finish (GAsyncResult	 *result,
 	g_return_val_if_fail (g_simple_async_result_is_valid (result, NULL, gth_image_apply_icc_profile_async), FALSE);
 	return g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), error);
 }
-
-
-void
-gth_icc_profile_free (GthICCProfile icc_profile)
-{
-#ifdef HAVE_LCMS2
-	if (icc_profile != NULL)
-		cmsCloseProfile ((cmsHPROFILE) icc_profile);
-#endif
-}
