@@ -39,6 +39,7 @@ enum {
 
 
 enum {
+	EXPANDED_LIST_HIGHLIGHTED_COLUMN,
 	EXPANDED_LIST_USED_COLUMN,
 	EXPANDED_LIST_INCONSISTENT_COLUMN,
 	EXPANDED_LIST_SEPARATOR_COLUMN,
@@ -62,6 +63,7 @@ enum {
 
 typedef struct {
 	char     *name;
+	gboolean  highlighted;
 	gboolean  used;
 	gboolean  suggested;
 	gboolean  inconsistent;
@@ -304,9 +306,9 @@ sort_tag_data (gconstpointer a,
 	TagData *tag_data_a = * (TagData **) a;
 	TagData *tag_data_b = * (TagData **) b;
 
-	if (tag_data_a->used && tag_data_b->used)
+	if (tag_data_a->highlighted && tag_data_b->highlighted)
 		return g_utf8_collate (tag_data_a->name, tag_data_b->name);
-	else if (tag_data_a->used || tag_data_b->used)
+	else if (tag_data_a->highlighted || tag_data_b->highlighted)
 		return tag_data_a->used ? -1 : 1;
 	else if (tag_data_a->suggested && tag_data_b->suggested)
 		return g_utf8_collate (tag_data_a->name, tag_data_b->name);
@@ -317,63 +319,81 @@ sort_tag_data (gconstpointer a,
 }
 
 
+static gboolean
+_tag_is_valid (const char *tag)
+{
+	if (tag == NULL)
+		return FALSE;
+	if (_g_utf8_all_spaces (tag))
+		return FALSE;
+	return TRUE;
+}
+
+
 static void
 update_expanded_list_from_entry (GthTagsEntry *self)
 {
 	char        **all_tags;
 	char        **used_tags;
 	TagData     **tag_data;
-	int           i;
+	int           i, t;
 	GtkTreeIter   iter;
 	gboolean      separator_required;
 
 	all_tags = g_strdupv (self->priv->tags);
 	used_tags = gth_tags_entry_get_tags (GTH_TAGS_ENTRY (self), FALSE);
 
-	tag_data = g_new (TagData *, g_strv_length (all_tags) + 1);
-	for (i = 0; all_tags[i] != NULL; i++) {
+	tag_data = g_new0 (TagData *, g_strv_length (all_tags) + 1);
+	for (i = 0, t = 0; all_tags[i] != NULL; i++) {
 		int j;
 
-		tag_data[i] = g_new0 (TagData, 1);
-		tag_data[i]->name = g_strdup (all_tags[i]);
-		tag_data[i]->used = FALSE;
-		tag_data[i]->inconsistent = (g_hash_table_lookup (self->priv->inconsistent, tag_data[i]->name) != NULL);
-		tag_data[i]->suggested = tag_data[i]->inconsistent;
-		for (j = 0; ! tag_data[i]->used && (used_tags[j] != NULL); j++)
-			if (g_utf8_collate (tag_data[i]->name, used_tags[j]) == 0) {
-				tag_data[i]->used = TRUE;
-				tag_data[i]->inconsistent = FALSE;
-				tag_data[i]->suggested = FALSE;
+		if (! _tag_is_valid (all_tags[i]))
+			continue;
+
+		tag_data[t] = g_new0 (TagData, 1);
+		tag_data[t]->name = g_strdup (all_tags[i]);
+		tag_data[t]->highlighted = FALSE;
+		tag_data[t]->used = FALSE;
+		tag_data[t]->inconsistent = (g_hash_table_lookup (self->priv->inconsistent, tag_data[t]->name) != NULL);
+		tag_data[t]->suggested = tag_data[t]->inconsistent;
+		for (j = 0; ! tag_data[t]->used && (used_tags[j] != NULL); j++)
+			if (g_utf8_collate (tag_data[t]->name, used_tags[j]) == 0) {
+				tag_data[t]->highlighted = TRUE;
+				tag_data[t]->used = TRUE;
+				tag_data[t]->inconsistent = FALSE;
+				tag_data[t]->suggested = FALSE;
 			}
 
-		if (! tag_data[i]->used)
-			for (j = 0; ! tag_data[i]->suggested && (self->priv->expanded_list.last_used[j] != NULL); j++)
-				if (g_utf8_collate (tag_data[i]->name, self->priv->expanded_list.last_used[j]) == 0)
-					tag_data[i]->suggested = TRUE;
+		if (! tag_data[t]->used)
+			for (j = 0; ! tag_data[t]->suggested && (self->priv->expanded_list.last_used[j] != NULL); j++)
+				if (g_utf8_collate (tag_data[t]->name, self->priv->expanded_list.last_used[j]) == 0)
+					tag_data[t]->suggested = TRUE;
+
+		t++;
 	}
-	tag_data[i] = NULL;
 
 	g_qsort_with_data (tag_data,
-			   g_strv_length (all_tags),
+			   g_strv_length (tag_data),
 			   sizeof (TagData *),
 			   sort_tag_data,
 			   NULL);
 
 	gtk_list_store_clear (self->priv->expanded_list.store);
 
-	/* used */
+	/* highlighted */
 
 	separator_required = FALSE;
 	for (i = 0; tag_data[i] != NULL; i++) {
 		GtkTreeIter iter;
 
-		if (! tag_data[i]->used)
+		if (! tag_data[i]->highlighted)
 			continue;
 
 		separator_required = TRUE;
 
 		gtk_list_store_append (self->priv->expanded_list.store, &iter);
 		gtk_list_store_set (self->priv->expanded_list.store, &iter,
+				    EXPANDED_LIST_HIGHLIGHTED_COLUMN, TRUE,
 				    EXPANDED_LIST_USED_COLUMN, TRUE,
 				    EXPANDED_LIST_INCONSISTENT_COLUMN, tag_data[i]->inconsistent,
 				    EXPANDED_LIST_SEPARATOR_COLUMN, FALSE,
@@ -384,6 +404,7 @@ update_expanded_list_from_entry (GthTagsEntry *self)
 	if (separator_required) {
 		gtk_list_store_append (self->priv->expanded_list.store, &iter);
 		gtk_list_store_set (self->priv->expanded_list.store, &iter,
+				    EXPANDED_LIST_HIGHLIGHTED_COLUMN, FALSE,
 				    EXPANDED_LIST_USED_COLUMN, FALSE,
 				    EXPANDED_LIST_INCONSISTENT_COLUMN, FALSE,
 				    EXPANDED_LIST_SEPARATOR_COLUMN, TRUE,
@@ -404,6 +425,7 @@ update_expanded_list_from_entry (GthTagsEntry *self)
 
 		gtk_list_store_append (self->priv->expanded_list.store, &iter);
 		gtk_list_store_set (self->priv->expanded_list.store, &iter,
+				    EXPANDED_LIST_HIGHLIGHTED_COLUMN, FALSE,
 				    EXPANDED_LIST_USED_COLUMN, FALSE,
 				    EXPANDED_LIST_INCONSISTENT_COLUMN, tag_data[i]->inconsistent,
 				    EXPANDED_LIST_SEPARATOR_COLUMN, FALSE,
@@ -414,6 +436,7 @@ update_expanded_list_from_entry (GthTagsEntry *self)
 	if (separator_required) {
 		gtk_list_store_append (self->priv->expanded_list.store, &iter);
 		gtk_list_store_set (self->priv->expanded_list.store, &iter,
+				    EXPANDED_LIST_HIGHLIGHTED_COLUMN, FALSE,
 				    EXPANDED_LIST_USED_COLUMN, FALSE,
 				    EXPANDED_LIST_INCONSISTENT_COLUMN, FALSE,
 				    EXPANDED_LIST_SEPARATOR_COLUMN, TRUE,
@@ -431,6 +454,7 @@ update_expanded_list_from_entry (GthTagsEntry *self)
 
 		gtk_list_store_append (self->priv->expanded_list.store, &iter);
 		gtk_list_store_set (self->priv->expanded_list.store, &iter,
+				    EXPANDED_LIST_HIGHLIGHTED_COLUMN, FALSE,
 				    EXPANDED_LIST_USED_COLUMN, FALSE,
 				    EXPANDED_LIST_INCONSISTENT_COLUMN, tag_data[i]->inconsistent,
 				    EXPANDED_LIST_SEPARATOR_COLUMN, FALSE,
@@ -693,7 +717,11 @@ update_entry_from_expanded_list (GthTagsEntry *self)
 	for (i = 0, scan = name_list; scan; scan = scan->next)
 		tags[i++] = scan->data;
 	tags[i] = NULL;
+	g_signal_handlers_block_by_func (G_OBJECT (self->priv->entry), text_changed_cb, self);
+	g_signal_handler_block (gth_main_get_default_monitor (), self->priv->monitor_event);
 	gth_tags_entry_set_tags (GTH_TAGS_ENTRY (self), tags);
+	g_signal_handler_unblock (gth_main_get_default_monitor (), self->priv->monitor_event);
+	g_signal_handlers_unblock_by_func (G_OBJECT (self->priv->entry), text_changed_cb, self);
 
 	g_free (tags);
 	_g_string_list_free (name_list);
@@ -1070,6 +1098,17 @@ expand_button_toggled_cb (GtkToggleButton *button,
 }
 
 
+static gboolean
+entry_focus_in_event_cb (GtkWidget *widget,
+	                 GdkEvent  *event,
+	                 gpointer   user_data)
+{
+	GthTagsEntry *self = user_data;
+	gtk_editable_set_position (GTK_EDITABLE (self->priv->entry), -1);
+	return GDK_EVENT_PROPAGATE;
+}
+
+
 static void
 gth_tags_entry_init (GthTagsEntry *self)
 {
@@ -1078,7 +1117,6 @@ gth_tags_entry_init (GthTagsEntry *self)
 	GtkCellRenderer   *renderer;
 	GtkWidget         *menu_item;
 
-	gtk_widget_set_can_focus (GTK_WIDGET (self), TRUE);
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (self)), GTK_STYLE_CLASS_COMBOBOX_ENTRY);
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_VERTICAL);
 	gtk_box_set_spacing (GTK_BOX (self), 3);
@@ -1123,6 +1161,10 @@ gth_tags_entry_init (GthTagsEntry *self)
 	gtk_entry_set_completion (GTK_ENTRY (self->priv->entry), self->priv->completion);
 	gtk_widget_show (self->priv->entry);
 	gtk_box_pack_start (GTK_BOX (hbox), self->priv->entry, TRUE, TRUE, 0);
+	g_signal_connect (self->priv->entry,
+			  "focus-in-event",
+			  G_CALLBACK (entry_focus_in_event_cb),
+			  self);
 
 	/* expand button */
 
@@ -1143,6 +1185,7 @@ gth_tags_entry_init (GthTagsEntry *self)
 							      G_TYPE_BOOLEAN,
 							      G_TYPE_BOOLEAN,
 							      G_TYPE_BOOLEAN,
+							      G_TYPE_BOOLEAN,
 							      G_TYPE_STRING);
 	self->priv->expanded_list.tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (self->priv->expanded_list.store));
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (self->priv->expanded_list.tree_view), FALSE);
@@ -1305,25 +1348,31 @@ gth_tags_entry_set_tags (GthTagsEntry  *self,
 			 char         **tags)
 {
 	GthTagsFile *tags_file;
+	GString     *valid_tags;
 	int          i;
 	gboolean     global_tags_changed = FALSE;
-	char        *s;
 
 	if ((tags == NULL) || (tags[0] == NULL)) {
 		gtk_entry_set_text (GTK_ENTRY (self->priv->entry), "");
 		return;
 	}
 
+	valid_tags = g_string_new ("");
 	tags_file = gth_main_get_default_tag_file ();
-	for (i = 0; tags[i] != NULL; i++)
+	for (i = 0; tags[i] != NULL; i++) {
+		if (! _tag_is_valid (tags[i]))
+			continue;
+		g_string_append (valid_tags, tags[i]);
+		g_string_append (valid_tags, ", ");
 		if (gth_tags_file_add (tags_file, tags[i]))
 			global_tags_changed = TRUE;
+	}
 	if (global_tags_changed)
 		gth_main_tags_changed ();
 
-	s = g_strjoinv (", ", tags);
-	gtk_entry_set_text (GTK_ENTRY (self->priv->entry), s);
-	g_free (s);
+	gtk_entry_set_text (GTK_ENTRY (self->priv->entry), valid_tags->str);
+
+	g_string_free (valid_tags, TRUE);
 }
 
 
@@ -1363,13 +1412,12 @@ gth_tags_entry_get_tags (GthTagsEntry *self,
 	all_tags = g_strsplit (gtk_entry_get_text (GTK_ENTRY (self->priv->entry)), ",", -1);
 	tags = g_new0 (char *, g_strv_length (all_tags) + 1);
 	for (i = 0, j = 0; all_tags[i] != NULL; i++) {
-		all_tags[i] = g_strstrip (all_tags[i]);
-		if (all_tags[i][0] != '\0') {
-			tags[j] = g_strdup (g_strstrip (all_tags[i]));
-			if (update_globals)
-				gth_tags_file_add (tags_file, tags[j]);
-			j++;
-		}
+		if (! _tag_is_valid (all_tags[i]))
+			continue;
+		tags[j] = g_strdup (g_strstrip (all_tags[i]));
+		if (update_globals)
+			gth_tags_file_add (tags_file, tags[j]);
+		j++;
 	}
 	g_strfreev (all_tags);
 
@@ -1392,14 +1440,20 @@ gth_tags_entry_set_tag_list (GthTagsEntry *self,
 	GList   *scan;
 
 	g_hash_table_remove_all (self->priv->inconsistent);
-	for (scan = inconsistent; scan; scan = scan->next)
-		g_hash_table_insert (self->priv->inconsistent, g_strdup (scan->data), GINT_TO_POINTER (1));
+	for (scan = inconsistent; scan; scan = scan->next) {
+		char *tag = scan->data;
+		if (! _tag_is_valid (tag))
+			continue;
+		g_hash_table_insert (self->priv->inconsistent, g_strdup (tag), GINT_TO_POINTER (1));
+	}
 
 	str = g_string_new ("");
 	for (scan = checked; scan; scan = scan->next) {
-		if (scan != checked)
-			g_string_append (str, ", ");
-		g_string_append (str, (char *) scan->data);
+		char *tag = scan->data;
+		if (! _tag_is_valid (tag))
+			continue;
+		g_string_append (str, tag);
+		g_string_append (str, ", ");
 	}
 	gth_tags_entry_set_tags_from_text (self, str->str);
 
@@ -1423,7 +1477,8 @@ gth_tags_entry_get_tag_list (GthTagsEntry  *self,
 		tags_v = gth_tags_entry_get_tags (self, update_globals);
 		*checked = NULL;
 		for (i = 0; tags_v[i] != NULL; i++)
-			*checked = g_list_prepend (*checked, g_strdup (tags_v[i]));
+			if (_tag_is_valid(tags_v[i]))
+				*checked = g_list_prepend (*checked, g_strdup (tags_v[i]));
 		*checked = g_list_reverse (*checked);
 	}
 
