@@ -45,7 +45,8 @@ typedef struct {
 GthOpData category_op_data[] = {
 	{ N_("is"), GTH_TEST_OP_CONTAINS, FALSE },
 	{ N_("is only"), GTH_TEST_OP_CONTAINS_ONLY, FALSE },
-	{ N_("is not"), GTH_TEST_OP_CONTAINS, TRUE }
+	{ N_("is not"), GTH_TEST_OP_CONTAINS, TRUE },
+	{ N_("matches"), GTH_TEST_OP_MATCHES, FALSE }
 };
 
 
@@ -184,9 +185,10 @@ monitor_tags_changed_cb (GthMonitor *monitor,
 static GtkWidget *
 gth_test_category_real_create_control (GthTest *base)
 {
-	GthTestCategory *test;
-	GtkWidget       *control;
-	int              i, op_idx;
+	GthTestCategory    *test;
+	GtkWidget          *control;
+	int                 i, op_idx;
+	GtkEntryCompletion *completion;
 
 	test = (GthTestCategory *) base;
 
@@ -229,6 +231,15 @@ gth_test_category_real_create_control (GthTest *base)
 		gtk_entry_set_text (GTK_ENTRY (test->priv->text_entry), test->priv->category);
 	gtk_widget_show (test->priv->combo_entry);
 
+	completion = gtk_entry_completion_new ();
+	gtk_entry_completion_set_popup_completion (completion, TRUE);
+	gtk_entry_completion_set_popup_single_match (completion, FALSE);
+	gtk_entry_completion_set_inline_completion (completion, TRUE);
+	gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (test->priv->tag_store));
+	gtk_entry_completion_set_text_column (completion, 0);
+	gtk_entry_set_completion (GTK_ENTRY (test->priv->text_entry), completion);
+	g_object_unref (completion);
+
 	g_signal_connect (G_OBJECT (test->priv->text_entry),
 			  "activate",
 			  G_CALLBACK (text_entry_activate_cb),
@@ -271,7 +282,8 @@ gth_test_category_real_match (GthTest     *test,
 	if (test_category->priv->category != NULL) {
 		GthMetadata   *metadata;
 		GList         *list, *scan;
-		char          *test_category_casefolded;
+		char          *test_category_casefolded = NULL;
+		GPatternSpec  *pattern = NULL;
 
 		list = NULL;
 		metadata = (GthMetadata *) g_file_info_get_attribute_object (file->info, gth_test_get_attributes (GTH_TEST (test_category)));
@@ -287,17 +299,33 @@ gth_test_category_real_match (GthTest     *test,
 				return test_category->priv->negative ? GTH_MATCH_YES : GTH_MATCH_NO;
 		}
 
-		test_category_casefolded = g_utf8_casefold (test_category->priv->category, -1);
 		for (scan = list; ! result && scan; scan = scan->next) {
-			char *category;
+			char *category = g_utf8_casefold (scan->data, -1);
 
-			category = g_utf8_casefold (scan->data, -1);
-			if (g_utf8_collate (category, test_category_casefolded) == 0)
-				result = TRUE;
+			switch (test_category->priv->op) {
+			case GTH_TEST_OP_CONTAINS:
+			case GTH_TEST_OP_CONTAINS_ONLY:
+				if (test_category_casefolded == NULL)
+					test_category_casefolded = g_utf8_casefold (test_category->priv->category, -1);
+				if (g_utf8_collate (category, test_category_casefolded) == 0)
+					result = TRUE;
+				break;
+
+			case GTH_TEST_OP_MATCHES:
+				if (pattern == NULL)
+					pattern = g_pattern_spec_new (test_category->priv->category);
+				result = g_pattern_match_string (pattern, scan->data);
+				break;
+
+			default:
+				break;
+			}
 
 			g_free (category);
 		}
 
+		if (pattern != NULL)
+			g_pattern_spec_free (pattern);
 		g_free (test_category_casefolded);
 	}
 
@@ -402,6 +430,16 @@ gth_test_category_real_update_from_control (GthTest  *base,
 }
 
 
+static void
+gth_test_category_real_focus_control (GthTest *base)
+{
+	GthTestCategory *self;
+
+	self = GTH_TEST_CATEGORY (base);
+	gtk_widget_grab_focus (self->priv->text_entry);
+}
+
+
 static GObject *
 gth_test_category_real_duplicate (GthDuplicable *duplicable)
 {
@@ -434,6 +472,7 @@ gth_test_category_class_init (GthTestCategoryClass *class)
 	test_class = (GthTestClass *) class;
 	test_class->create_control = gth_test_category_real_create_control;
 	test_class->update_from_control = gth_test_category_real_update_from_control;
+	test_class->focus_control = gth_test_category_real_focus_control;
 	test_class->match = gth_test_category_real_match;
 }
 
