@@ -132,6 +132,8 @@ test_combo_box_changed_cb (GtkComboBox     *scope_combo_box,
 
 		test = gth_main_get_registered_object (GTH_TYPE_TEST, test_name);
 		gth_test_selector_set_test (self, test);
+		gth_test_selector_focus (self);
+
 		g_object_unref (test);
 	}
 }
@@ -197,7 +199,7 @@ gth_test_selector_construct (GthTestSelector *self,
 	GList           *scan;
 
 	gtk_box_set_spacing (GTK_BOX (self), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (self), 2);
+	gtk_container_set_border_width (GTK_CONTAINER (self), 0);
 
 	/* scope combo box */
 
@@ -343,9 +345,10 @@ void
 gth_test_selector_set_test (GthTestSelector *self,
 			    GthTest         *test)
 {
+	GthTest   *old_test;
 	GtkWidget *control;
 
-	_g_object_unref (self->priv->test);
+	old_test = self->priv->test;
 	if (test != NULL)
 		self->priv->test = (GthTest *) gth_duplicable_duplicate (GTH_DUPLICABLE (test));
 	else
@@ -376,6 +379,8 @@ gth_test_selector_set_test (GthTestSelector *self,
 		gtk_container_add (GTK_CONTAINER (self->priv->control_box),
 				   self->priv->control);
 	}
+
+	_g_object_unref (old_test);
 }
 
 
@@ -396,3 +401,11 @@ gth_test_selector_can_remove (GthTestSelector *self,
 {
 	gtk_widget_set_sensitive (self->priv->remove_button, value);
 }
+
+
+void
+gth_test_selector_focus (GthTestSelector *self)
+{
+	if (self->priv->test != NULL)
+		gth_test_focus_control (self->priv->test);
+}
