@@ -19,6 +19,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <math.h>
 #include <config.h>
 #include <stdlib.h>
 #include <string.h>
@@ -85,11 +86,13 @@ enum {
         PROP_DATA_TYPE,
         PROP_DATA_AS_STRING,
         PROP_DATA_AS_INT,
+	PROP_DATA_AS_DOUBLE,
         PROP_DATA_AS_DATE,
         PROP_GET_DATA,
         PROP_OP,
         PROP_NEGATIVE,
-        PROP_MAX_INT
+	PROP_MAX_INT,
+	PROP_MAX_DOUBLE
 };
 
 
@@ -100,11 +103,13 @@ struct _GthTestSimplePrivate
 		char   *s;
 		gint64  i;
 		GDate  *date;
+		gdouble f;
 	} data;
 	GthTestGetData   get_data;
 	GthTestOp        op;
 	gboolean         negative;
 	gint64           max_int;
+	double           max_double;
 	GPatternSpec    *pattern;
 	gboolean         has_focus;
 	GtkWidget       *text_entry;
@@ -117,11 +122,11 @@ struct _GthTestSimplePrivate
 };
 
 
-static DomDomizableInterface* dom_domizable_parent_iface = NULL;
+static DomDomizableInterface *dom_domizable_parent_iface = NULL;
 static GthDuplicableInterface *gth_duplicable_parent_iface = NULL;
 
 
-static void gth_test_simple_dom_domizable_interface_init (DomDomizableInterface * iface);
+static void gth_test_simple_dom_domizable_interface_init (DomDomizableInterface *iface);
 static void gth_test_simple_gth_duplicable_interface_init (GthDuplicableInterface *iface);
 
 
@@ -303,6 +308,51 @@ create_control_for_integer (GthTestSimple *test)
 	return control;
 }
 
+static GtkWidget *
+create_control_for_double (GthTestSimple *test)
+{
+	GtkWidget *control;
+	int        i, op_idx;
+
+	control = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+
+	/* text operation combo box */
+
+	test->priv->text_op_combo_box = gtk_combo_box_text_new ();
+	gtk_widget_show (test->priv->text_op_combo_box);
+
+	op_idx = 0;
+	for (i = 0; i < G_N_ELEMENTS (int_op_data); i++) {
+		gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (test->priv->text_op_combo_box),
+						_(int_op_data[i].name));
+		if ((int_op_data[i].op == test->priv->op) && (int_op_data[i].negative == test->priv->negative))
+			op_idx = i;
+	}
+	gtk_combo_box_set_active (GTK_COMBO_BOX (test->priv->text_op_combo_box), op_idx);
+
+	g_signal_connect (G_OBJECT (test->priv->text_op_combo_box),
+			  "changed",
+			  G_CALLBACK (size_op_combo_box_changed_cb),
+			  test);
+
+	/* spin button */
+
+	test->priv->spinbutton = gtk_spin_button_new_with_range (0, test->priv->max_double, 0.01);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (test->priv->spinbutton), test->priv->data.f);
+	gtk_widget_show (test->priv->spinbutton);
+
+	g_signal_connect (G_OBJECT (test->priv->spinbutton),
+			  "value-changed",
+			  G_CALLBACK (spinbutton_changed_cb),
+			  test);
+
+	/**/
+
+	gtk_box_pack_start (GTK_BOX (control), test->priv->text_op_combo_box, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (control), test->priv->spinbutton, FALSE, FALSE, 0);
+
+	return control;
+}
 
 static GtkWidget *
 create_control_for_size (GthTestSimple *test)
@@ -563,6 +613,10 @@ gth_test_simple_real_create_control (GthTest *test)
 	case GTH_TEST_DATA_TYPE_DATE:
 		control = create_control_for_date (GTH_TEST_SIMPLE (test));
 		break;
+
+	case GTH_TEST_DATA_TYPE_DOUBLE:
+		control = create_control_for_double (GTH_TEST_SIMPLE (test));
+		break;
 	}
 
 	return control;
@@ -652,6 +706,32 @@ test_integer (GthTestSimple *test,
 }
 
 
+static gboolean
+test_double (GthTestSimple *test,
+             gdouble        value)
+{
+	gboolean result = FALSE;
+
+	switch (test->priv->op) {
+	case GTH_TEST_OP_EQUAL:
+		result = FLOAT_EQUAL (value, test->priv->data.f);
+		break;
+
+	case GTH_TEST_OP_LOWER:
+		result = (value < test->priv->data.f);
+		break;
+
+	case GTH_TEST_OP_GREATER:
+		result = (value > test->priv->data.f);
+		break;
+
+	default:
+		break;
+	}
+	return result;
+}
+
+
 static gboolean
 test_date (GthTestSimple *test,
            GDate         *date)
@@ -705,6 +785,18 @@ _gth_test_simple_get_int (GthTestSimple *test,
 }
 
 
+static gdouble
+_gth_test_simple_get_double (GthTestSimple *test,
+			     GthFileData   *file)
+{
+	gdouble value;
+
+	test->priv->get_data (GTH_TEST (test), file, (gpointer)&value, NULL);
+
+	return value;
+}
+
+
 static GthMatch
 gth_test_simple_real_match (GthTest   *test,
 			    GthFileData   *file)
@@ -726,6 +818,10 @@ gth_test_simple_real_match (GthTest   *test,
 		result = test_integer (test_simple, _gth_test_simple_get_int (test_simple, file));
 		break;
 
+	case GTH_TEST_DATA_TYPE_DOUBLE:
+		result = test_double (test_simple, _gth_test_simple_get_double (test_simple, file));
+		break;
+
 	case GTH_TEST_DATA_TYPE_STRING:
 		data = _gth_test_simple_get_pointer (test_simple, file, &data_destroy_func);
 		result = test_string (test_simple, data);
@@ -783,6 +879,17 @@ gth_test_simple_real_create_element (DomDomizable *base,
 		}
 		break;
 
+	case GTH_TEST_DATA_TYPE_DOUBLE:
+		dom_element_set_attribute (element, "op", _g_enum_type_get_value (GTH_TYPE_TEST_OP, self->priv->op)->value_nick);
+		if (self->priv->op != GTH_TEST_OP_NONE) {
+			if (self->priv->negative)
+				dom_element_set_attribute (element, "negative", self->priv->negative ? "true" : "false");
+			value = g_strdup_printf ("%f", self->priv->data.f);
+			dom_element_set_attribute (element, "value", value);
+			g_free (value);
+		}
+		break;
+
 	case GTH_TEST_DATA_TYPE_STRING:
 		dom_element_set_attribute (element, "op", _g_enum_type_get_value (GTH_TYPE_TEST_OP, self->priv->op)->value_nick);
 		if (self->priv->op != GTH_TEST_OP_NONE) {
@@ -846,6 +953,10 @@ gth_test_simple_real_load_from_element (DomDomizable *base,
 		gth_test_simple_set_data_as_int (self, atol (value));
 		break;
 
+	case GTH_TEST_DATA_TYPE_DOUBLE:
+		gth_test_simple_set_data_as_double (self, atof (value));
+		break;
+
 	case GTH_TEST_DATA_TYPE_SIZE:
 		gth_test_simple_set_data_as_size (self, atol (value));
 		break;
@@ -887,6 +998,21 @@ update_from_control_for_integer (GthTestSimple  *self,
 }
 
 
+static gboolean
+update_from_control_for_double (GthTestSimple  *self,
+				GError        **error)
+{
+	GthOpData op_data;
+
+	op_data = int_op_data[gtk_combo_box_get_active (GTK_COMBO_BOX (self->priv->text_op_combo_box))];
+	self->priv->op = op_data.op;
+	self->priv->negative = op_data.negative;
+	gth_test_simple_set_data_as_double (self, gtk_spin_button_get_value  (GTK_SPIN_BUTTON (self->priv->spinbutton)));
+
+	return TRUE;
+}
+
+
 static gboolean
 update_from_control_for_size (GthTestSimple  *self,
 			      GError        **error)
@@ -974,6 +1100,10 @@ gth_test_simple_real_update_from_control (GthTest  *base,
 		retval = update_from_control_for_integer (self, error);
 		break;
 
+	case GTH_TEST_DATA_TYPE_DOUBLE:
+		retval = update_from_control_for_double (self, error);
+		break;
+
 	case GTH_TEST_DATA_TYPE_SIZE:
 		retval = update_from_control_for_size (self, error);
 		break;
@@ -1005,6 +1135,7 @@ gth_test_simple_real_focus_control (GthTest *base)
 
 	switch (self->priv->data_type) {
 	case GTH_TEST_DATA_TYPE_INT:
+	case GTH_TEST_DATA_TYPE_DOUBLE:
 		gtk_widget_grab_focus (self->priv->spinbutton);
 		break;
 
@@ -1044,6 +1175,10 @@ gth_test_simple_real_duplicate (GthDuplicable *duplicable)
 		gth_test_simple_set_data_as_int (new_test, test->priv->data.i);
 		break;
 
+	case GTH_TEST_DATA_TYPE_DOUBLE:
+		gth_test_simple_set_data_as_double (new_test, test->priv->data.f);
+		break;
+
 	case GTH_TEST_DATA_TYPE_SIZE:
 		gth_test_simple_set_data_as_size (new_test, test->priv->data.i);
 		break;
@@ -1061,6 +1196,7 @@ gth_test_simple_real_duplicate (GthDuplicable *duplicable)
 	new_test->priv->op = test->priv->op;
 	new_test->priv->negative = test->priv->negative;
 	new_test->priv->max_int = test->priv->max_int;
+	new_test->priv->max_double = test->priv->max_double;
 
 	return (GObject *) new_test;
 }
@@ -1091,6 +1227,11 @@ gth_test_simple_set_property (GObject      *object,
 		test->priv->data.i = g_value_get_int (value);
 		break;
 
+	case PROP_DATA_AS_DOUBLE:
+		_gth_test_simple_free_data (test);
+		test->priv->data.f = g_value_get_double (value);
+		break;
+
 	case PROP_DATA_AS_DATE:
 		_gth_test_simple_free_data (test);
 		test->priv->data.date = g_value_dup_boxed (value);
@@ -1112,6 +1253,10 @@ gth_test_simple_set_property (GObject      *object,
 		test->priv->max_int = g_value_get_int (value);
 		break;
 
+	case PROP_MAX_DOUBLE:
+		test->priv->max_double = g_value_get_double (value);
+		break;
+
 	default:
 		break;
 	}
@@ -1141,6 +1286,10 @@ gth_test_simple_get_property (GObject    *object,
 		g_value_set_int (value, test->priv->data.i);
 		break;
 
+	case PROP_DATA_AS_DOUBLE:
+		g_value_set_double (value, test->priv->data.f);
+		break;
+
 	case PROP_DATA_AS_DATE:
 		g_value_set_boxed (value, test->priv->data.date);
 		break;
@@ -1161,6 +1310,10 @@ gth_test_simple_get_property (GObject    *object,
 		g_value_set_int (value, test->priv->max_int);
 		break;
 
+	case PROP_MAX_DOUBLE:
+		g_value_set_double (value, test->priv->max_double);
+		break;
+
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -1211,6 +1364,15 @@ gth_test_simple_class_init (GthTestSimpleClass *class)
                                                            G_MAXINT,
                                                            0,
                                                            G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+					 PROP_DATA_AS_DOUBLE,
+					 g_param_spec_double ("data-as-double",
+                                                              "Data as double",
+							      "The data value as a double precision real number",
+							      G_MINDOUBLE,
+							      G_MAXDOUBLE,
+							      1.0,
+							      G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
 					 PROP_DATA_AS_DATE,
 					 g_param_spec_boxed ("data-as-date",
@@ -1239,7 +1401,6 @@ gth_test_simple_class_init (GthTestSimpleClass *class)
                                                                "Whether to negate the test result",
                                                                FALSE,
                                                                G_PARAM_READWRITE));
-
 	g_object_class_install_property (object_class,
 					 PROP_MAX_INT,
 					 g_param_spec_int ("max-int",
@@ -1249,6 +1410,15 @@ gth_test_simple_class_init (GthTestSimpleClass *class)
                                                            G_MAXINT,
                                                            0,
                                                            G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+					 PROP_MAX_DOUBLE,
+					 g_param_spec_int ("max-double",
+                                                           "Max double",
+                                                           "Max value for doubles",
+                                                           G_MININT,
+                                                           G_MAXINT,
+                                                           0.0,
+                                                           G_PARAM_READWRITE));
 }
 
 
@@ -1273,6 +1443,7 @@ static void
 gth_test_simple_init (GthTestSimple *test)
 {
 	test->priv = g_new0 (GthTestSimplePrivate, 1);
+	test->priv->data_type = GTH_TEST_DATA_TYPE_NONE;
 }
 
 
@@ -1296,6 +1467,16 @@ gth_test_simple_set_data_as_int (GthTestSimple *test,
 }
 
 
+void
+gth_test_simple_set_data_as_double (GthTestSimple *test,
+			            gdouble        f)
+{
+	_gth_test_simple_free_data (test);
+	test->priv->data_type = GTH_TEST_DATA_TYPE_DOUBLE;
+	test->priv->data.f = f;
+}
+
+
 void
 gth_test_simple_set_data_as_size (GthTestSimple *test,
 			          guint64        i)
